/*
	Copyright (c) 2004-2009, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is a compiled version of Dojo, built for deployment and not for
	development. To get an editable version, please visit:

		http://dojotoolkit.org

	for documentation and information on getting the source.
*/

if(!dojo._hasResource['epages.style.processor']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.style.processor'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.style.processor $Revision: 1.43 $

*/
dojo.provide('epages.style.processor');






epages.style.Processor = function (/*DomNode */container,/*String*/imageBaseUrl, /*Boolean*/ cachePrevention, /*Document?*/doc) {
	// summary:
	//    initialize the style processor.
	//    all changes of input and select elements of the given container starts the style processing.
	// container: DomNode [deprecated] - no longer in use (!!!fixme) -> just pass undefined
	// imageBaseUrl: String - object (current object) related base url e.g. /WebRoot/Store/Shops/DemoShop/Styles/Milestones
	// cachePrevention: Boolean - append cache prevention string (timestamp) to file refernces e.g. WebRoot/[..]/MediaGallery/CampingSite.gif?CachePrevention=1282899274013
	// doc: Document? - target document for style rules
	// example:
	//  |  var styleProcessor = new epages.style.Processor($('myform'),'/WebRoot/Store/Shops/DemoShop/');
	//  | styleProcessor.addRule(
	//  |    'NavBarFont',
	//  |    ".(%Class%) div, .(%Class%) span, .(%Class%) table, .(%Class%) td, .(%Class%) p, .(%Class%) ul li, .(%Class%) ol li, .(%Class%) blockquote, .(%Class%) input"
	//  |  );
	//  |  styleProcessor.addInput(
	//  |    'NavBarFont',                   // rule name
	//  |    'NavBarTop',                    // CSS ClassName
	//  |    'font-family',                  // CSS AttributeName
	//  |    $('TopFontFamily'),             // input
	//  |    function(el) {                  // callback
	//  |      if(el.value="") { alert("new value is empty"); }
	//  |    }
	//  |  );
	//  |  styleProcessor.fill();
	this.rules  = new epages.lang.Hash();
	this.inputs = new epages.lang.Hash();
	this.imageBaseUrl = imageBaseUrl;
	this.cachePrevention = cachePrevention;
	this.doc = doc || dojo.doc;
};

epages.style.Processor.prototype = {
	rules       : undefined,    // epages.lang.Hash - registerd css rules -> key: <css-selector:String> value <css-attributes:String>
	inputs      : undefined,    // epages.lang.Hash - registerd input elements (event trigger) e.g. {}
	imageBaseUrl: undefined,    // String - base url of file location
	cachePrevention: undefined, // Boolean - append cache prevention string on file url or not
	doc         : undefined,    // window.document - document to work on
	defaults    : {
		'text-decoration' : function (Value) { return 'text-decoration: '  + (Value == "1" ? 'underline' : 'none'  ); },
		'font-style' :      function (Value) { return 'font-style: '       + (Value == "1" ? 'italic'    : 'normal'); },
		'font-weight':      function (Value) { return 'font-weight: '      + (Value == "1" ? 'bold'      : 'normal'); },
		'color':            function (Value) { return 'color: ' + Value + ' !important';},
		'navbar-horizontalalign':   function (Value) {
			if(Value == "left") {
				return 'text-align:'+Value+'; margin: 0 auto 0 0';
			} else if(Value == "right") {
				return 'text-align:'+Value+'; margin: 0 0 0 auto';
			} else {
				return 'text-align:'+Value+'; margin: 0 auto 0 auto';
			}
		},
		'box-horizontalalign':   function (Value) {
			if(Value == "left") {
				return 'margin-left:0!important; margin-right:auto!important';
			} else if(Value == "right") {
				return 'margin-right:0!important; margin-left:auto!important';
			} else {
				return 'margin-left:auto!important; margin-right:auto!important';
			}
		},
		'background-image':       function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+')';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-right': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top right';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-right-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top right !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-left': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top left';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-left-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top left !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-bottom-right-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: bottom right !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-bottom-left-norepeat':  function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: bottom left !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-clear':   function(Value) {
			 return 'background-image: none';
		},
		'background-repeat': function(Value) {
			return 'background-repeat: '+ (Value=='1' ? 'repeat' : 'no-repeat');
		},
		'width-and-max-width': function(Value) {
			 return 'width:'+Value+' !important; max-width:'+Value;
		}
	},    // Object - hash with default css attribute function -> key <css-attribute> value <function>

	defaultCallbacks : {
		'update-button-active' : function (object, navbar) {
			this.updateButtonStyle(navbar.replace(/^NavBar/,''), 'ButtonActive');
		},
		'update-button-both' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			this.updateButtonStyle(navbar, 'Button');
			this.updateButtonStyle(navbar, 'ButtonActive');
		},
		'set-imageset-left-backgound' : function (object, navbar) {
			if (object.value=="0") {
				this.set($('ImageSetLeft'+navbar.replace(/^NavBar/,'')+'BackgroundImage'));
			}
		},
		'set-imageset-right-backgound' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BackgroundImage'));
		},
		'set-imageset-right-boxbody' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BoxBodyImage'));
		},
		'set-imageset-right-box' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BoxImage'));
		},
		'set-imageset-boxbody-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BoxBodyImage'));
				this.set($('ImageSetLeft'+navbar+'BoxBodyImage'));
			}
		},
		'set-imageset-box-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BoxImage'));
				this.set($('ImageSetLeft'+navbar+'BoxImage'));
			}
		},
		'set-imageset-background-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BackgroundImage'));
				this.set($('ImageSetLeft'+navbar+'BackgroundImage'));
			}
		},
		'set-boximage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BoxImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BoxImage')); // set uploaded image again
			if(object.value=="") {
				this.set($('ImageSetRight'+navbar+'BoxImage'));
				this.set($('ImageSetLeft'+navbar+'BoxImage'));
			} else {
				this.set($(navbar+'BoxImageTiling')); // set tiling (repeat)
			}
		},
		'set-boxbodyimage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BoxBodyImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BoxBodyImage')); // set uploaded image again
			if(object.value=="") {
				this.set($('ImageSetRight'+navbar+'BoxBodyImage'));
				this.set($('ImageSetLeft'+navbar+'BoxBodyImage'));
			} else {
				this.set($(navbar+'BoxBodyImageTiling')); // set tiling (repeat)
			}
		},
		'set-backgroundimage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BackgroundImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BackgroundImage')); // set uploaded image again
			if(object.value=="") {
				if ($('ImageSetRight'+navbar+'BackgroundImage') != null){
					this.set($('ImageSetRight'+navbar+'BackgroundImage'));
				}
				this.set($('ImageSetLeft'+navbar+'BackgroundImage'));
			} else {
				this.set($(navbar+'BackgroundImageTiling')); // set tiling (repeat)
			}
		}
	},	// Object - hash with default callback functions to set css to a designable element -> key <set-elmentname> value <function>

	attachCachePrevention: function() {
	// summary: generate cache prevention string e.g. "?CachePrevention=1234567890"
		var date = new Date();
		return (this.cachePrevention) ? "?CachePrevention="+date.getTime() : "";	// String
	},

	addRule: function(/*String*/ruleName, /*String*/CSSKey, /*Object*/CSSAttributes) {
		// summary:
		//    Adds a style rule to the processor.
		//    The rule name is a short keyword for a CSS key.
		//    The CSSKey can include a placeholder '(%Class)' (also multiple times) for a CSS class,
		//    which will be defined via the 'addInput' method.
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor.addRule(
		//  |    'NavBarFont',
		//  |    ".(%Class%) div, .(%Class%) span, .(%Class%) table, .(%Class%) td, .(%Class%) p, .(%Class%) ul li, .(%Class%) ol li, .(%Class%) blockquote, .(%Class%) input"
		//  |  );
		//  |  styleProcessor.addRule('ContentPadding', ".ContentArea");
		//  |  styleProcessor.addRule('NavBarContainer', ".(%Class%) .PropertyContainer");
		//  |  styleProcessor.addRule('ThisClass', ".(%Class%)");
		if (CSSAttributes === undefined) {
			CSSAttributes = {};
		}
		var rule = new epages.lang.Hash();
		rule.set('Key', CSSKey);
		rule.set('Attributes', CSSAttributes);
		this.rules.set(ruleName, rule);
	},

	addInput: function(/*String*/ruleName, /*String*/className, /*String*/attributeName, /*Object|String*/inputObject, /*Function?*/callback) {
		// summary:
		//    Adds a input element to the processor.
		//    Attention: The name of input fields has to be unique.
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor.addInput(
		//  |    'NavBarFont',                   // rule name
		//  |    'NavBarTop',                    // CSS ClassName
		//  |    'font-family',                  // CSS AttributeName
		//  |    $('TopFontFamily'),             // input
		//  |  );
		//  |  styleProcessor.addInput('NavBarContainer', 'NavBarLeft', 'width', $('BoxWidth'), function (el) {
		//  |    $('LeftNavBarWidth').value = (parseInt($('BoxWidth').getValue().replace(/px/, '')) + parseInt($('LeftPaddingRight').getValue().replace(/px/, '')) + parseInt($('LeftPaddingLeft').getValue().replace(/px/, ''))) + 'px';
		//  |    styleProcessor.set($('LeftNavBarWidth'));
		//  |  });
		if (typeof inputObject == 'string') {
			var inputObjectId = inputObject;
			inputObject = $(inputObjectId);
			if (inputObject == null) {
				//console.debug('epages.style.Processor.addInput: could not find input with id ' + inputObjectId + ', ruleName:' + ruleName);
				return;
			}
		} else if (inputObject == null) {
			//console.debug('epages.style.Processor.addInput cant add undefined object, rulename: ' + ruleName + '. attributeName:' + attributeName);
			return;
		}
		if (callback !== undefined && typeof callback != 'function') {
			callback = this.defaultCallbacks[callback];
		}
		// console.debug('epages.style.Processor.addInput add object for rule: ' + ruleName + '.');
		// console.debug(inputObject);
		// console.debug('epages.style.Processor.addInput add object: ' + inputObject.name + '.');
		dojo.connect(inputObject, 'onchange', this, '_set');
		this.inputs.set(inputObject.name, {
			rule:       ruleName,
			className:  className,
			attribute:  attributeName,
			target:     inputObject,
			callback:   callback
		});
	},

	_updateStyleSheet: function(/* String */ rule, /*String*/ text) {
		// summary:
		//    add a CSS rule with given text.
		// rule: String - CSS Selector
		// rule: String - CSS Text (Attributes) e.g. color: red;
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor._updateStyleSheet('.NavBarTop div, .NavBarTop span', 'padding-left: 5px');

		// we have to be sure that we don't conflict with pseudo classes like :hover
		if(!rule.match("html")) {
			rule = "html body " + rule.replace(/,/g, " , html body");
		}
		if(!rule.match(" a") && !/important/.test(text)) {
			text += ' !important';
		}
		if (epages.Browser.engine == 'MSIE') {
			var rules = rule.split(/,\s+/);
			var sheet = this.doc.styleSheets[this.doc.styleSheets.length-1];
			for( var i=0,l=rules.length ; i<l ; i++ ) {
				sheet.addRule(rules[i], text);
			}
		} else {
			var styleRules = this.doc.getElementById('StyleRules');
			if(!styleRules){
				styleRules = this.doc.createElement("div");
				styleRules.id = "StyleRules";
				this.doc.body.appendChild(styleRules);
			}
			var styleContainer = this.doc.createElement("div");
			styleContainer.innerHTML = "<div class='HideElement'>.<style type='text/css'>" + rule + '{' + text + '}' + "</style></div>";
			styleRules.appendChild(styleContainer);
		}
	},

	_set: function (/*Event*/evt) {
		// summary:
		//    call back function for event observer.
		var inputNode = evt.target;
		if (inputNode.name.match(/image/i) && inputNode.value.match(/^MediaGallery\//)) {
			inputNode.value = epages.lang.uri.getRelative(this.imageBaseUrl, epages.vars.SiteRoot + '/' + inputNode.value);
		}
		var isError=inputNode.getAttribute("ep_error");
		if (isError != 1){
			this.set(inputNode, true);
		}
	},

	set: function (/*Object*/inputObject, /*Boolean?*/doCallback) {
		// summary:
		//    set style sheet information for this input element.
		//    Returns true if input rule was processed.
		if (doCallback === undefined) {
			doCallback = false;
		}
		var value = $E(inputObject).get();
		if(value === undefined) {
			console.warn('Value is undefined in '+this.declaredClass+'. inputObject:', inputObject);
		}
		var ruleInput = this.inputs.get(inputObject.name);
		if (ruleInput === undefined) {
			//console.debug('no rule for inputfield "' + inputObject.id + '" (' + inputObject.name + ')');
			return 0; // Boolean
		}
		var ruleName      = ruleInput.rule;      // eg: NavBarFont
		var className     = ruleInput.className; // eg: NavBarTop
		var attributeName = ruleInput.attribute; // eg: font-family
		var KeyTemplate = this.rules.get(ruleName).get('Key');
		var CSSKey = KeyTemplate.replace( /\(%Class%\)/g , className);
		// get value definition, could be a function/string/undefined
		var attributeDefinition = this.rules.get(ruleName).get('Attributes')[attributeName];
		if (attributeDefinition === undefined) {
			attributeDefinition = this.defaults[attributeName];
		}

		// get real css value
		var CSSValue = undefined;
		switch (typeof attributeDefinition) {
			case 'function':
				CSSValue = attributeDefinition(value, this);
				break;
			case 'string':
				CSSValue = attributeDefinition.replace( /\(%Value%\)/gi , value);
				break;
			default:
				CSSValue = attributeName + ': ' + value;
				break;
		}

		this._updateStyleSheet(CSSKey, CSSValue);
		if (doCallback && ruleInput.callback !== undefined) {
			ruleInput.callback.call(this, inputObject, className);
		}
		return 1; // Boolean
	},

	fill: function () {
		// summary:
		//    calls processor rules for each input (set stylesheet info to input field values).
		var currentThis = this;
		var iterator = function(el) {
			currentThis.set(el.target, true);
		};
		var values = this.inputs.values();
		$A(values).each(iterator);
	},

	updateButtonStyle: function (navBar, buttonType) {
		// summary: helper function for button style rule update
		// description: Sets or clears the current and the opposite button image. Furthermore it sets the
		//              left and right ImageSet images on demand and activates image tiling.
		// example:
		// | styleProcessor.addInput('NavigationElement','Header','background-image-left-norepeat',$('HeaderButton'),function(el) {
		// |   updateButtonStyle('Header','Button');
		// | });
		this.set($(navBar+buttonType));
		this.set($(navBar+"Right"+buttonType));
		if(($(navBar+buttonType+'Hidden').value=="0" || $(navBar+buttonType+'Hidden').value=="") &&
			 $(navBar+buttonType).value=="" &&
			 $(navBar+"Right"+buttonType).value=="") {
			// (hide ImageSet=0 or empty) && (no left image) && (no right image) --> show ImageSet images
			this.set($('ImageSetLeft'+navBar+buttonType));
			this.set($('ImageSetRight'+navBar+buttonType));
		} else {
			// set image tiling style (background-repeat)
			// this is only possible with uploaded images - not with image set images
			this.set($(navBar+buttonType+'Tiling'));
		}
	}
};

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.Toolbackgroundimage']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.Toolbackgroundimage'] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolbackgroundimage $Revision: 1.46 $

*/

dojo.provide('epages.cartridges.de_epages.design.widget.Toolbackgroundimage');




epages.require('ep_shop_upload', 'epages.uploader');


dojo['require']('epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery');

dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbackgroundimage",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label               : "",
		fileName            : "",
		imageType           : "",
		imageSetHidden      : "",
		imagesetLeft        : "",
		imagesetRight       : "",
		imageTiling         : "",
		disableTiling       : "0",
		allowImageSetTiling : "0",
		disableImageSet     : "0",
		objectId            : "",
		'class'             : "",
		uploadAction      	: "UploadFiles",
		fileNameNode        : null,
		formElement					: 'NewFile',
		userConfirmation		: false,
		/**
		 * template properties
		 */
		templateType        : "tablerow",
		defaultTemplateType : "tablerow",
		templateString:"<tr class=\"ToolbackgroundImage\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n\n      <input dojoAttachPoint=\"fileNameNode\"\n             id=\"${imageType}\"\n             name=\"${imageType}\"\n             value=\"${fileName}\"\n             type=\"hidden\"\n             />\n\n      <!-- buttons -->\n      <div dojoAttachPoint=\"clearImageNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n            <i class=\"Sprite ico_s_delete\"></i>{Delete}\n      </div>\n      <div dojoAttachPoint=\"clearImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_delete\"></i>{ClearImageSet}\n      </div>\n\n      <div dojoAttachPoint=\"restoreImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_redo\"></i>{RestoreImageSet}\n      </div>\n\n      <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n           dojoAttachPoint=\"toolMediaGalleryWidget\"\n           validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n           multiSelect=\"false\"\n           webImagesOnly=\"true\"\n           opener=\"Toolbackgroundimage\"\n           ></div>\n\n      <div class=\"ClearBoth\"></div>\n      <div dojoAttachPoint=\"tilingAreaNode\" class=\"LeftSmallMargin\">\n        <input dojoAttachPoint=\"tilingCheckboxNode\"\n               name=\"TilingCheckBox\"\n               class=\"Checkbox AlignMiddle\"\n               type=\"text\"\n               ep_noundo=\"1\"\n               />{Tiling}\n\n        <input dojoAttachPoint=\"imageTilingNode\"\n               type=\"hidden\"\n               name=\"${objectId}:${imageType}Tiling\"\n               id=\"${imageType}Tiling\"\n               value=\"${imageTiling}\" />\n      </div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageHiddenNode\"\n           id=\"${imageType}Hidden\"\n           name=\"${objectId}:${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${imageType}\"\n           name=\"ImageSetLeft${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input dojoAttachPoint=\"imageSetRightNode\"\n           id=\"ImageSetRight${imageType}\"\n           name=\"ImageSetRight${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n  </td>\n</tr>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),

		_templateMapping:{
			'tablerow' : {templateString:"<tr class=\"ToolbackgroundImage\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n\n      <input dojoAttachPoint=\"fileNameNode\"\n             id=\"${imageType}\"\n             name=\"${imageType}\"\n             value=\"${fileName}\"\n             type=\"hidden\"\n             />\n\n      <!-- buttons -->\n      <div dojoAttachPoint=\"clearImageNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n            <i class=\"Sprite ico_s_delete\"></i>{Delete}\n      </div>\n      <div dojoAttachPoint=\"clearImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_delete\"></i>{ClearImageSet}\n      </div>\n\n      <div dojoAttachPoint=\"restoreImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_redo\"></i>{RestoreImageSet}\n      </div>\n\n      <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n           dojoAttachPoint=\"toolMediaGalleryWidget\"\n           validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n           multiSelect=\"false\"\n           webImagesOnly=\"true\"\n           opener=\"Toolbackgroundimage\"\n           ></div>\n\n      <div class=\"ClearBoth\"></div>\n      <div dojoAttachPoint=\"tilingAreaNode\" class=\"LeftSmallMargin\">\n        <input dojoAttachPoint=\"tilingCheckboxNode\"\n               name=\"TilingCheckBox\"\n               class=\"Checkbox AlignMiddle\"\n               type=\"text\"\n               ep_noundo=\"1\"\n               />{Tiling}\n\n        <input dojoAttachPoint=\"imageTilingNode\"\n               type=\"hidden\"\n               name=\"${objectId}:${imageType}Tiling\"\n               id=\"${imageType}Tiling\"\n               value=\"${imageTiling}\" />\n      </div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageHiddenNode\"\n           id=\"${imageType}Hidden\"\n           name=\"${objectId}:${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${imageType}\"\n           name=\"ImageSetLeft${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input dojoAttachPoint=\"imageSetRightNode\"\n           id=\"ImageSetRight${imageType}\"\n           name=\"ImageSetRight${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n  </td>\n</tr>\n"},
			'xlicon'   : {templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"}
		},

		/**
		 * widget properties
		 */
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			dojo.addClass(this.domNode,this['class']);

			if(this.objectId != '') {
				this.fileNameNode.name=this.objectId+":"+this.fileNameNode.name;
			}


			// pass callback function to toolMediaGalleryWidget
			this.toolMediaGalleryWidget.fileNameNode = this.fileNameNode;
			this.toolMediaGalleryWidget.onApply = dojo.hitch(this, function(selectedElements) {
				if(selectedElements.length>0) {
					var pathFromSite=selectedElements[0].pathFromSite();
					if(pathFromSite!=null) {
						this.setFileName(pathFromSite);
					}
				}
			});

			if(this.disableTiling=="1") {
				this.tilingAreaNode.style.display='none';
			}

			this.tilingCheckboxNode = new epages.widget.FormElement({}, this.tilingCheckboxNode).elementNode;

			// check tiling checkbox if necessary
			if(this.imageTiling == "1"){
				epages.event.fire(this.tilingCheckboxNode,"click");
			}

			// init events
			this._appendEvents();
			// init buttons
			this._showButtons();
		},

		/**
		 * public methods
		 */

		setFileName: function(pathFromSite) {
			this.fileNameNode.value = pathFromSite;
			epages.event.fire(this.fileNameNode, "change");
		},

		/**
		 * private methods
		 */

		_appendEvents: function() {
		// summary: append onclick and onchange events

			// add value handler
			this.connect(this.clearImageNode,      'onclick', '_clearImage');
			this.connect(this.clearImageSetNode,   'onclick', '_clearImageSet');
			this.connect(this.restoreImageSetNode, 'onclick', '_restoreImageSet');
			this.connect(this.tilingCheckboxNode,  'onclick', '_toggleImageTiling');

			this.connect(this.fileNameNode,        'onchange', '_showButtons');
			this.connect(this.imageHiddenNode,     'onchange', '_showButtons');
			this.connect(this.imageTilingNode,     'onchange', '_showButtons');
		},

		_clearImage: function(evt) {
		// summary: clears the value of "image file name" input and throws change event
			if(this.userConfirmation){
				var me = this;
				dojo.publish("uimessage/show", [
					this.translation.get("HeadLineDeleteFile"),
					this.translation.get("File") + ': ' + me.label,
					'Dialog',
					{
						titleBar: this.translation.get("TitleDeleteFile"),
						sizeClass:"Large",
						typeClass:"Confirmation",
						buttons: [{
							label: this.translation.get("Delete"),
							cssClass: 'Active',
							onclick: function() {
								this._modalDialogWidget.hide();
								me.fileNameNode.value="";
								epages.event.fire(me.fileNameNode, "change");
							}
						},
						{
							label: this.translation.get("Cancel"),
							onclick: function() {
								this._modalDialogWidget.hide();
							}
						}]
					}
				]);
			}
			else{
				this.fileNameNode.value="";
				epages.event.fire(this.fileNameNode, "change");
				/*
				if(this.imageHiddenNode.value=="1") {
					epages.event.fire(this.noUndoImageHiddenNode,"change");
				}
				*/
			}
		},

		_clearImageSet: function(evt) {
		// summary: set value of "imageHidden" input to "1" and throw change event
			this.imageHiddenNode.value="1";
			epages.event.fire(this.imageHiddenNode,"change");
		},

		_restoreImageSet: function(evt) {
		// summary: set value of "imageHidden" input to "0" and throw change events
			this.imageHiddenNode.value="0";
			epages.event.fire(this.imageHiddenNode,"change");
			epages.event.fire(this.imageSetNode,"change");
		},

		_showButtons: function() {
		// summary: decides which button is visible
			if(this.imageTilingNode.value=='1') {
				this.tilingCheckboxNode.checked=true;
			} else {
				this.tilingCheckboxNode.checked=false;
			}

			if(this.fileNameNode.value!="") {						// image uploaded
				this.clearImageNode.style.display="";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="none";
				if(this.disableTiling!="1") {
					this.tilingAreaNode.style.display="";
				}
			} else if(this.imageHiddenNode.value!="1"){ // show image set
				this.clearImageNode.style.display="none";
				if(this.disableImageSet=="0") {
					this.clearImageSetNode.style.display="";
				}
				else {
					this.clearImageSetNode.style.display="none";
				}
				this.restoreImageSetNode.style.display="none";
				if(this.allowImageSetTiling=="0" || this.disableTiling=="1") {
					this.tilingAreaNode.style.display="none";
				} else {
					this.tilingAreaNode.style.display="";
				}
			} else {																		// no image/ image set hidden
				this.clearImageNode.style.display="none";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="";
				this.tilingAreaNode.style.display="none";
			}
		},

		_toggleImageTiling: function(evt) {
		// summary: hidden input / checkbox handler set
		// description: Handles the value of the hidden input element which depends on the visible checkbox.
		//		Afterwards it fires an change event to trigger the display handler (_showButtons).
			if(this.tilingCheckboxNode.checked==true) {
				this.imageTilingNode.value=1;
			} else {
				this.imageTilingNode.value=0;
			}
			epages.event.fire(this.imageTilingNode,"change");
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfontfamily"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfontfamily"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolfontfamily $Revision: 1.18 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolfontfamily");





dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolfontfamily",
	[epages.widget.LocalizedWidget, dijit._Contained],
	{
		/**
		 * public properties
		 */
		label               : '',
		fontFamily          : '',
		fontType            : '', /* Headline, Paragraph, Link, ... */
		objectId            : '',

		/**
		 * private properties
		 */
		templateType        : "tablerow",
		defaultTemplateTyp  : "tablerow",
		_templateMapping:{
			'tablerow' : {templateString:"<tr class=\"Toolfontfamily\">\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td class=\"FontSize\">\n      <select dojoAttachPoint=\"fontSelectNode\"\n              id=\"${fontType}\"\n              name=\"${objectId}:${fontType}\"\n              >\n        <option style=\"font-family:Arial, Verdana, Helvetica\"                                value=\"Arial, Verdana, Helvetica\"                            >Arial</option>\n        <option style=\"font-family:'Courier New', Verdana, Helvetica\"                        value=\"Courier New, Verdana, Helvetica\"                      >Courier New</option>\n        <option style=\"font-family:georgia, 'Times New Roman', arial, sans-serif\"            value=\"georgia, Times New Roman, arial, sans-serif\"          >Georgia</option>\n        <option style=\"font-family:'Lucida Sans Unicode', 'Lucida Sans', Verdana, Helvetica\" value=\"Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica\" >Lucida Sans</option>\n        <option style=\"font-family:Tahoma, Verdana, Helvetica\"                               value=\"Tahoma, Verdana, Helvetica\"                           >Tahoma</option>\n        <option style=\"font-family:'Times New Roman', Times\"                                 value=\"Times New Roman, Times\"                               >Times New Roman</option>\n        <option style=\"font-family:'Trebuchet MS', Verdana, Arial, Helvetica\"                value=\"Trebuchet MS, Verdana, Arial, Helvetica\"              >Trebuchet MS</option>\n        <option style=\"font-family:Verdana, Arial, Helvetica\"                                value=\"Verdana, Arial, Helvetica\"                            >Verdana</option>\n      </select>\n  </td>\n</tr>\n"},
			'xlicon'   : {templateString:"<div class=\"Toolfontfamily WithXLIcon\">\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\" dojoAttachEvent=\"onclick:showFontMenu\">\n    <i class=\"Sprite ico_xl_font\" title=\"{SelectFont}\"></i><br />\n    ${label}<br />\n    <img src=\"${imagePath}/img_extend.png\"\n     alt=\"{SelectFont}\" title=\"{SelectFont}\" />\n  </div>\n  <input type=\"hidden\"\n         dojoAttachPoint=\"fontSelectNode\"\n         id=\"${fontType}\"\n         name=\"${objectId}:${fontType}\" >\n  <div dojoAttachPoint=\"menuContainerNode\"></div>\n</div>\n"}
		},

		_lastSelected       : null,
		_menuWidget         : null,
		_popup              : null,
		_fonts: {
			'Arial'           : "Arial, Verdana, Helvetica",
			'Courier New'     : "Courier New, Verdana, Helvetica",
			'Georgia'         : "georgia, Times New Roman, arial, sans-serif",
			'Lucida Sans'     : "Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica",
			'Tahoma'          : "Tahoma, Verdana, Helvetica",
			'Times New Roman' : "Times New Roman, Times",
			'Trebuchet MS'    : "Trebuchet MS, Verdana, Arial, Helvetica",
			'Verdana'         : "Verdana, Arial, Helvetica"
		},

		/**
		 * widget properties
		 */
		widgetType      : 'Toolfontfamily',
		templateString:"<tr class=\"Toolfontfamily\">\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td class=\"FontSize\">\n      <select dojoAttachPoint=\"fontSelectNode\"\n              id=\"${fontType}\"\n              name=\"${objectId}:${fontType}\"\n              >\n        <option style=\"font-family:Arial, Verdana, Helvetica\"                                value=\"Arial, Verdana, Helvetica\"                            >Arial</option>\n        <option style=\"font-family:'Courier New', Verdana, Helvetica\"                        value=\"Courier New, Verdana, Helvetica\"                      >Courier New</option>\n        <option style=\"font-family:georgia, 'Times New Roman', arial, sans-serif\"            value=\"georgia, Times New Roman, arial, sans-serif\"          >Georgia</option>\n        <option style=\"font-family:'Lucida Sans Unicode', 'Lucida Sans', Verdana, Helvetica\" value=\"Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica\" >Lucida Sans</option>\n        <option style=\"font-family:Tahoma, Verdana, Helvetica\"                               value=\"Tahoma, Verdana, Helvetica\"                           >Tahoma</option>\n        <option style=\"font-family:'Times New Roman', Times\"                                 value=\"Times New Roman, Times\"                               >Times New Roman</option>\n        <option style=\"font-family:'Trebuchet MS', Verdana, Arial, Helvetica\"                value=\"Trebuchet MS, Verdana, Arial, Helvetica\"              >Trebuchet MS</option>\n        <option style=\"font-family:Verdana, Arial, Helvetica\"                                value=\"Verdana, Arial, Helvetica\"                            >Verdana</option>\n      </select>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.fontSelectNode.value=this.fontFamily;
			if(this.clickNode) {
				this._menuWidget= new epages.widget.Menu();

				for(var i in this._fonts){
					this._addFontRow(i);
				}
				this._menuWidget.startup();
			}
		},

		_addFontRow: function(/*integer*/i) {
		// summary: add menu entry (link)
			var parentWidget=this;
			var entry= new dijit.MenuItem({
				label: i,
				iconClass: 'MinimizeIcon',
				onClick: function() {
					parentWidget.switchFont(i);
					dijit.popup.close(parentWidget._menuWidget);
				},
				id: 'font'+i
			});

			entry.containerNode.style.fontFamily= this._fonts[i];
			entry.containerNode.style.fontSize= '12px';
			this._menuWidget.addChild(entry);

			if(this.fontFamily == this._fonts[i]) {
				this._lastSelected=entry.domNode;
				dojo.addClass(this._lastSelected, "Selected" );
			}

		},

		showFontMenu:	function()	{
		// summary: show menu
		// summary: open the popup to the side of the current menu item
			dijit.popup.open({
				parent:this.domNode,
				popup:this._menuWidget,
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		},

		switchFont: function(/*ObjectIndex*/fontIndex) {
			this.fontSelectNode.value=this._fonts[fontIndex];
			epages.event.fire(this.fontSelectNode,"change");
			if(this._lastSelected) {
				dojo.removeClass(this._lastSelected, "Selected" );
			}
			this._lastSelected=$$('font'+fontIndex).domNode;
			dojo.addClass(this._lastSelected, "Selected" );
		}
	});


}

if(!dojo._hasResource["epages.event.sensitiveborders"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event.sensitiveborders"] = true;
dojo.provide("epages.event.sensitiveborders");


epages.event.sensitiveBorders = {
	// summary: Enable the user to scroll the page by mouse position.
	// description: With this enabled the user can scroll the page by moving the cursor to the particular border in which direction he wants the page to move.
	// example: epages.event.sensitiveBorders.enable(window);
	//          epages.event.sensitiveBorders.disable();

	_SENSITIVE_WIDTH: 80, // px
	_SCROLL_DELAY: 150, // ms
	_SCROLL_SPEED: 2, // ms
	_SCROLL_AMOUNT: 6, // px

	_topInterval: null,
	_leftInterval: null,
	_rightInterval: null,
	_bottomInterval: null,
	_scrollTimeout: null,

	_mouseMoveHandle: null,
	_localDojo: null,
	_localWindow: null,

	maxScrollRight: 0,
	maxScrollBottom: 0,

	_resetTimers: function() {
		clearInterval(this._topInterval);
		clearInterval(this._leftInterval);
		clearInterval(this._rightInterval);
		clearInterval(this._bottomInterval);
		clearTimeout(this._scrollTimeout);
		this._topInterval = null;
		this._leftInterval = null;
		this._rightInterval = null;
		this._bottomInterval = null;
		this._scrollTimeout = null;
	},

	_checkSensitiveArea: function(evt) {
		var moveLeft = evt.clientX < this._SENSITIVE_WIDTH;
		var moveRight = evt.clientX > this.maxScrollRight - this._SENSITIVE_WIDTH;
		var moveTop = evt.clientY < this._SENSITIVE_WIDTH;
		var moveBottom = evt.clientY > this.maxScrollBottom - this._SENSITIVE_WIDTH;
		if(!(moveLeft || moveRight || moveTop || moveBottom)) {
			this._resetTimers();
		}else if(!this._scrollTimeout) {
			this._scrollTimeout = setTimeout(dojo.hitch(this, function() {
				this._resetTimers();
				if(moveLeft) {
					this._leftInterval = setInterval(dojo.hitch(this, function() {
						this._localWindow.scrollBy("-" + this._SCROLL_AMOUNT, 0);
					}), this._SCROLL_SPEED);
				}
				if(moveRight) {
					this._rightInterval = setInterval(dojo.hitch(this, function() {
						// prevent the browser from scrolling into nirvana (especially if user is currently using d&d)
						if((this._localDojo.body().parentNode.scrollLeft || this._localDojo.body().scrollLeft) <= (this._localDojo.body().offsetWidth - this.maxScrollRight)) {
							this._localWindow.scrollBy(this._SCROLL_AMOUNT, 0);
						}
					}), this._SCROLL_SPEED);
				}
				if(moveTop) {
					this._topInterval = setInterval(dojo.hitch(this, function() {
						this._localWindow.scrollBy(0, "-" + this._SCROLL_AMOUNT);
					}), this._SCROLL_SPEED);
				}
				if(moveBottom) {
					this._bottomInterval = setInterval(dojo.hitch(this, function() {
						// prevent the browser from scrolling into nirvana (especially if user is currently using d&d)
						if((this._localDojo.body().parentNode.scrollTop || this._localDojo.body().scrollTop) <= (this._localDojo.body().offsetHeight - this.maxScrollBottom)) {
							this._localWindow.scrollBy(0, this._SCROLL_AMOUNT);
						}
					}), this._SCROLL_SPEED);
				}
			}), this._SCROLL_DELAY);
		}
	},

	enable: function(windowRef /* window reference (optional) */) {
		this._localWindow = windowRef || window;
		this._localDojo = this._localWindow.dojo;
		var bodyNode = this._localDojo.body();

		this.maxScrollRight = (epages.Browser.engine == "WebKit" ? bodyNode.clientWidth : bodyNode.parentNode.clientWidth);
		this.maxScrollBottom = (epages.Browser.engine == "WebKit" ? bodyNode.clientHeight : bodyNode.parentNode.clientHeight);

		if(!bodyNode.parentNode.className.match("SensitiveBorders")) {
			this._localDojo.addClass(bodyNode.parentNode, "SensitiveBorders");
			this._mouseMoveHandle = this._localDojo.connect(bodyNode, "mousemove", this, "_checkSensitiveArea");
		}
	},

	disable: function() {
		this._resetTimers();
		this._localDojo.disconnect(this._mouseMoveHandle);
		this._localDojo.removeClass(this._localDojo.body().parentNode, "SensitiveBorders");
	}
}

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.dragdrop"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.dragdrop"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.dragdrop");




$DND = /*epages.cartridges.de_epages.presentation.Dragdrop*/function (/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	return new epages.cartridges.de_epages.presentation.Dragdrop(handlerId,elements, screenContainer);
};

epages.cartridges.de_epages.presentation.Dragdrop = function(/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	this.elements = [];

	this.screenContainer=(screenContainer) ? screenContainer : (epages.Browser.engine == "WebKit" ? document.documentElement : dojo.body());

	if(elements !== undefined){
		for(var el in elements){
			this.addElement(elements[el]);
		}
	}

	this.handlerId=handlerId;
	this.isDragging = false;
	this._appendBodyEvents();
};

epages.cartridges.de_epages.presentation.Dragdrop.prototype = {
	dragObject : undefined,
	isDragging : undefined,
	handlerId  : undefined,
	elements   : undefined,
	screenContainer : undefined,

	addElement: function(el) {
		if(el.clickNode) {  // is object
			var clickEl = el.clickNode;
			var moveEl  = el.clickNode;
			if(el.moveNode){
				moveEl = el.moveNode;
			}else{
				el.moveNode = moveEl;
			}
			this.elements.push(el);
		} else {            // is DOM node
			var clickEl = el;
			var moveEl  = el;
			// transform to object
			this.elements.push({
				clickNode: el,
				moveNode: el
			});
		}

		//get drag drop element
		dojo.connect(clickEl,'onmousedown', this, '_startDragging');
		dojo.connect(moveEl, 'onmousedown', this, '_setMoveTarget');

		clickEl.style.cursor="move";
		moveEl.style.position="relative";
	},

	_appendBodyEvents: function() {
		dojo.connect(document, 'onmousemove', this, '_onmousemove');
		dojo.connect(document, 'onmouseup', this, '_onmouseup');
	},

	_getCurrentElement: function(node) {
		for(el in this.elements) {
			if(node===this.elements[el].moveNode) {
				return this.elements[el];
			}
		}
		return false;
	},

	_getScreenContainerOffset: function() {
		if(this.screenContainer.nodeName!="BODY"){
			var pos=$E(this.screenContainer).getAbsolutePosition();
		} else {
			var pos = {};
			pos.y=0;
			pos.x=0;
		}
		return pos;
	},

	_getScrollOffset: function() {
		var pos = {};

		var relativeScrollParent = (epages.Browser.engine == "MSIE" && this.screenContainer.tagName == "BODY") ? this.screenContainer.parentNode : this.screenContainer;
		pos.y = relativeScrollParent.scrollTop;
		pos.x = relativeScrollParent.scrollLeft;

		return pos;
	},

	_setNodeSize: function(node) {
		var nodeWidth=node.clientWidth;
		if(nodeWidth == 0){
			nodeWidth=node.offsetWidth;
		}
		node.style.width = nodeWidth+"px";
		if (node.outerHeight) {
			node.style.height = node.outerHeight+"px";
		} else {
			node.style.height = node.clientHeight+"px";
		}
	},

	_clearNodeSize: function(node) {
		node.style.width= "";
		node.style.height= "";
	},

	_getPositionOnScreenContainer: function(evt) {
		var scrollOffset=this._getScrollOffset();
		if(epages.Browser.engine=="MSIE") {
			var x= evt.clientX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.clientY-this.dragObject.offsetY+scrollOffset.y;
		} else {
			var x= evt.pageX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.pageY-this.dragObject.offsetY+scrollOffset.y;
		}
		return { x:x, y:y };
	},

	_onmousemove: function(evt) {
		if(this.dragObject && this.isDragging) {
			dojo.addClass(this.dragObject.domElement,"IsDragging");

			dojo.addClass(document.getElementsByTagName("body")[0],"IsDropArea");

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);
			// set position
			this._setPosition(pos.x-screenOffset.x,pos.y-screenOffset.y);
			this.dragObject.domElement.style.position="absolute";
			this.dragObject.domElement.style.zIndex="100000";

			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/move', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX-((epages.Browser.engine != "WebKit")?window.pageXOffset:0),
				mouseY: pos.y+this.dragObject.offsetY-((epages.Browser.engine != "WebKit")?window.pageYOffset:0),
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);

		}
	},

	_onmouseup: function(evt) {
		if(this.isDragging) {

			epages.event.sensitiveBorders.disable();

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);

			var currentElement=this._getCurrentElement(this.dragObject.domElement);

			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/drop', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);

			
			// resize the parent cell (if webkit-engine)
			if((epages.Browser.engine == "WebKit") && (this.dragObject.domElement.parentNode.nodeName.toLowerCase() == "td")){
				this.dragObject.domElement.parentNode.style.width = this.dragObject.domElement.style.width;
			}

			// execute elements onDrop function
			if(currentElement && currentElement.onDrop){
				currentElement.onDrop();
			}
			// reset
			this._clearNodeSize(this.dragObject.domElement);

			dojo.removeClass(this.dragObject.domElement,"IsDragging");

			dojo.removeClass(document.getElementsByTagName("body")[0],"IsDropArea");

			this.isDragging = false;
			this.dragObject.domElement.style.position="relative";
			this.dragObject.domElement.style.left="";
			this.dragObject.domElement.style.top="";
			this.dragObject.domElement.style.zIndex="";
			this.dragObject.domElement.style.zoom="1";
			this.dragObject = undefined;

			document.body.onselectstart = function(){};
			document.body.style.MozUserSelect = "";
		}
	},

	_startDragging: function(evt) {
		document.body.onselectstart = function() {
			return false;
		};
		document.body.style.MozUserSelect = "none";
		epages.event.sensitiveBorders.enable();
		this.isDragging = true;
		dojo.publish('dragdrop'+this.handlerId+'/beforeStart',[{
			event: evt
		}]);
	},

	_setMoveTarget: function(evt) {
	// _startDragging() should always be executed before _setMoveTarget()
		var moveNode = evt.target;
		var dragNode = evt.currentTarget;
		
		var distance = {};
		if(dragNode !== moveNode) {
			distance = $E(moveNode).getPositionToParent(dragNode);
		} else {
			distance.x = 0;
			distance.y = 0;
		}

		this.dragObject = {
			domElement: dragNode,
			offsetX   : (epages.Browser.engine.match("MSIE")) ? evt.offsetX: evt.layerX + distance.x,
			offsetY   : (epages.Browser.engine.match("MSIE")) ? evt.offsetY: evt.layerY  + distance.y
		};
		// debug offset coordinates & domElement
		// console.debug(this.dragObject.offsetX + " ; "+ this.dragObject.offsetY + " / "+ this.dragObject.domElement.style.position);

		if(this.isDragging) {
			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			if(currentElement.forceSize){
				this._setNodeSize(this.dragObject.domElement);
			}

			var pos=this._getPositionOnScreenContainer(evt);

			dojo.publish('dragdrop'+this.handlerId+'/start', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: this.dragObject
			}]);
		}
	},

	_setPosition: function(x,y) {
		var posCorrection = {x: 0, y: 0};

		var parentDomNode = this.dragObject.domElement.parentNode;

		// get the first relative positioned element or the body
		while(parentDomNode.nodeName.toLowerCase()!="body" && (dojo.style(parentDomNode, 'position')!="relative")){  // alternative: && !dojo.hasClass(parentDomNode, 'PropertyContainer')
			parentDomNode = parentDomNode.parentNode;
		}
		
		posCorrection = $E(parentDomNode).getAbsolutePosition();

		this.dragObject.domElement.style.left = (x-posCorrection.x-((epages.Browser.engine == "WebKit")? 0 : window.pageXOffset))+'px';
		this.dragObject.domElement.style.top = (y-posCorrection.y-((epages.Browser.engine == "WebKit")? 0 : window.pageYOffset))+'px';
	}

};

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Tooliconset"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Tooliconset"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Tooliconset $Revision: 1.23.92.1 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Tooliconset");






dojo.declare(
	"epages.cartridges.de_epages.design.widget.Tooliconset",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		url             : '?',
		objectId        : epages.vars.ObjectID,
		languageId      : epages.vars.Locale.languageId,
		iconset         : '',
		undoWidget      : undefined,
		undoWidgetId    : 'undoWidget',
		objectId        : '',
		imagePath       : epages.themeUrl('images'),

		/**
		 * private properties
		 */
		_dialogWidget   : undefined,
		_htmlUndo       : undefined,
		_oldIconset     : undefined,
		//these are the css-classes that have an icon from the iconset as background-image
		_cssClassesWithIcon : {
			'LinkPrintView'   : 'ico_s_printer.png',
			'LinkBasket'      : 'ico_s_basket.png',
			'Action'          : 'img_actionlink.png',
			'TreeNode'        : {
				'NoSubCategories'       : 'img_tree_empty.png',
				'HasSubCategories'      : 'img_tree_plus.png',
				'HasSubCategoriesMinus' : 'img_tree_minus.png'
			}
		},
		/**
		 * constants
		 */
		 //css class for elements that have an icon from the iconset inside
		CSSCLASS: 'Icon',

		/**
		 * widget properties
		 */
		templateType       : 'default',
		defaultTemplateType: 'default',
		templateString:"<div class=\"WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\"></i>\n  <br/>{ChangeIconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		_templateMapping: {
			'default' : {templateString:"<div class=\"WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\"></i>\n  <br/>{ChangeIconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n"},
			'xlicon'  : {templateString:"<div class=\"XLIconWidget WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\" ></i>\n  <br />{Iconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n"}
		},

		postMixInProperties: function() {
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates');
			this.inherited("postMixInProperties", arguments);
			if(epages.vars.Iconset){
				this.iconset = epages.vars.Iconset;
			}else{
				console.warn("epages.vars.Iconset not defined in "+this.declaredClass);
			}
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.connect(this.iconNode,'onclick', '_onClickIconNode');
			this.undoWidget = $$(this.undoWidgetId);
			if (this.undoWidget === undefined) {
				console.warn(this.id+' : undo widget not found in '+this.declaredClass);
			} else {
				this._htmlUndo = this.undoWidget.getUndoObject();
				this._htmlUndo.setDefaultValue(this.hiddenInput);
				this.connect(this.hiddenInput,'onchange', '_onChangeHiddenInput');
			}
		} ,

		_createDialog:function(){
			 var json = new epages.io.Json();
			var params = {
				'ViewAction': 'JSONSnippet',
					'TemplateAction': 'IconsetSnippet',
					'TemplateLanguageID': this.languageId,
					'ObjectID': this.objectId,
					'TemplateLanguageID': this.languageId
			};
				var output = json.loadSync(this.url, params);
			 var me = this;
			var buttons = [{
				label: this.translation.get("Apply"),
				cssClass: 'Active',
				onclick: function() {
					this._modalDialogWidget.hide();
					me._onApplyClick();
				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					this._modalDialogWidget.hide();
				}
			}];
			this._dialogWidget = new epages.widget.Modaldialog({
				id: "Tooliconset_DialogWidget",
				options:{
					title : this.translation.get("ChangeIconset"),
					width : 620,
					height: 200,
					content: output.data.snippet
				},
				buttons : buttons
			});
			document.body.appendChild(this._dialogWidget.domNode);

			var nodeList = dojo.query('img',this._dialogWidget.domNode);
			var img = new Image();
				img.onload = dojo.hitch(this,function(){ this._dialogWidget.layout(); });
				img.src = dojo.attr( nodeList[nodeList.length-1] , 'src');
		},

		_onClickIconNode: function(){
			if(!this._dialogWidget){
				this._createDialog();
			}
			this._dialogWidget.show();
		},

		_onApplyClick:function(){
			var newIconset = '';
			var radioButtons = document.getElementsByName('LayoutIconSet');
			for( var i=0,iLength=radioButtons.length ; i<iLength ; i++ ){
				if(radioButtons[i].checked){
					newIconset = radioButtons[i].value;
				}
			}
			if(newIconset != '' && newIconset != this.iconset){
				if(this.undoWidget){
					this.hiddenInput.value = newIconset;
					this._htmlUndo.addInput(this.hiddenInput);
				}
				this._oldIconset = this.iconset;
				this.iconset = newIconset;
				this._changeIconsInPage(this._oldIconset,this.iconset);
				dojo.publish("Tooliconsset/IconsetChanged",[]);
			}
		},

		_changeIconsInPage:function(oldIconset,newIconset){
			var iframeDoc = $('EmbeddedStorefront').contentDocument || $('EmbeddedStorefront').contentWindow.document;
			var iframeWin = $('EmbeddedStorefront').contentWindow;
			for(var el in this._cssClassesWithIcon){
				var cssClass = el;
				var elementsArray = iframeWin.epages.html.getElementsByClassName(cssClass,iframeDoc);
				for( var i=0,iLength=elementsArray.length ; i<iLength ; i++ ){
					if(typeof this._cssClassesWithIcon[cssClass] == 'string'){
						var icon = this._cssClassesWithIcon[cssClass];
						if (dojo.style(elementsArray[i],'background-image') !== 'none') {
							elementsArray[i].style.cssText = 'background-image: url('+epages.vars.StoreRoot+'/'+newIconset+'/'+icon+') !important';
						}
					}
					else if(typeof this._cssClassesWithIcon[cssClass] =='object'){
						for(var elm in this._cssClassesWithIcon[cssClass]){
							var cssSubClass = elm;
							var subIcon = this._cssClassesWithIcon[cssClass][elm];
							if(dojo.hasClass(elementsArray[i],cssSubClass)){
								elementsArray[i].style.cssText = 'background: url('+epages.vars.StoreRoot+'/'+newIconset+'/'+subIcon+')0px 3px no-repeat !important';
							}
						}
					}
				}
			}
			var elementsArray = iframeWin.epages.html.getElementsByClassName(this.CSSCLASS, iframeDoc);
			for( var i=0,iLength=elementsArray.length ; i<iLength ; i++ ){
				if(elementsArray[i].filters) {
					elementsArray[i].filters(0).src = elementsArray[i].filters(0).src.replace(oldIconset, newIconset);
				}else{
					elementsArray[i].style.cssText = "background-image: " + $('EmbeddedStorefront').contentWindow.dojo.getComputedStyle(elementsArray[i]).backgroundImage.replace(oldIconset, newIconset) + " !important";
				}
			}
		},

		_onChangeHiddenInput:function(evt){
			var iconset = evt.currentTarget.value;
			this._oldIconset = this.iconset;
			this.iconset = iconset;
			this._changeIconsInPage(this._oldIconset,this.iconset);
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Switchcontentpreview"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Switchcontentpreview"] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Switchcontentpreview $Revision: 1.6 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Switchcontentpreview");






dojo.declare(
	"epages.cartridges.de_epages.design.widget.Switchcontentpreview",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */

		/**
		 * private properties
		 */
		_previews     : null,
		_menuWidget   : null,
		_lastPreview : null,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"Switchcontentpreview EnableHover\">\n  {Preview} <br />\n  <div class=\"PreviewSelector\"\n       dojoAttachPoint=\"previewSelectorNode\"\n       dojoAttachEvent=\"onclick:showPreviewMenu\">\n    <div class=\"PreviewLabel\" dojoAttachPoint=\"previewLabelNode\"></div>\n    <div class=\"DropDownArrow\"></div>\n  </div>\n  <div dojoAttachPoint=\"menuContainerNode\"></div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this._menuWidget= new epages.widget.Menu();
			this._previews = $H({});
		},

		switchPreview: function(id) {
			var newPreview = this._previews.get(id);
			var lastPreviewNode = (this._lastPreview) ? this._lastPreview.previewNode : undefined;
			var lastToolsNode = (this._lastPreview) ? $(this._lastPreview.toolsNodeId) : undefined;
			var toolsNode = $(newPreview.toolsNodeId);

			if(this._lastPreview == null || lastPreviewNode != newPreview.previewNode) {
				// preview node
				if(lastPreviewNode){
					lastPreviewNode.style.display = "none";
				}
				var formatted_label = epages.format.slice(newPreview.label, 15);

				this.previewLabelNode.innerHTML=formatted_label;
				if(newPreview.label !== formatted_label){
					this.previewLabelNode.title = newPreview.label;
				}else{
					this.previewLabelNode.title = "";
				}
				this.previewSelectorNode.style.backgroundImage = 'url('+newPreview.imageUrl+')';
				newPreview.previewNode.style.display="";
				// tools node
				if(lastToolsNode){
					lastToolsNode.style.display="none";
				}
				if(toolsNode){
					toolsNode.style.display="";
				}

				this._lastPreview = newPreview;
			}
		},

		addPreview: function(id, opt) {
			var parentWidget=this;
			var entry= new dijit.MenuItem({
				label: opt.label,
				iconClass: '',
				onClick: function() {
					parentWidget.switchPreview(id);
					dijit.popup.close(parentWidget._menuWidget);
				}
			});
			entry.iconNode.style.background = 'url('+document.location.protocol + '//' + document.location.hostname + '/' + opt.imageUrl+') no-repeat top left';
			this._menuWidget.addChild(entry);

			this._previews.set(id, opt);
		},

		showPreviewMenu:	function()	{
		// summary: show menu
		// open the popup to the side of the current menu item
			dijit.popup.open({
				parent:this.domNode,
				popup:this._menuWidget,
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.EditorPlaceholder');




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.EditorPlaceholder",
	[dijit._Widget, dijit._Templated],
	{
		ep_info: '',
		_info: undefined,
		base64: new epages.string.Base64,
		src : epages.vars.StoreRoot + '/BO/icons/general_img_transparentpixel.gif',

		templateString: '<img width="" height="" ep_group="" ep_info="${ep_info}" title="" alt="" style="" class="epItemContent" src="${src}" />',

		decodeInfo: function(string) {
			if(string && string != ''){
				var info = eval("(" + this.base64.decode(string) + ")");
				if (info.formData !== undefined){ 
					info.formData = $H(info.formData);
				}
				return info;
			}
	},

		postMixInProperties:function(){
			this.inherited("postMixInProperties", arguments);
			this._info = this.decodeInfo(this.ep_info);
		},
		postCreate: function(){
			this.inherited("postCreate", arguments);
			if(this._info && this._info != ''){
				if(this._info.width == "100%") {
					this.domNode.setAttribute('width',this.domNode.parentNode.offsetWidth);
				}else {
					this.domNode.setAttribute('width',this._info.width);
				}
				if(this._info.height == "100%") {
					this.domNode.setAttribute('height',this.domNode.parentNode.offsetHeight);
				}else {
					this.domNode.setAttribute('height',this._info.height);
				}
				this.domNode.setAttribute('alt',this._info.title);
				this.domNode.setAttribute('title',this._info.title);
				this.domNode.style.backgroundImage = 'url('+epages.locationWebRoot(this._info.preview)+')';
				this.domNode.setAttribute('ep_group',this._info.group);
				var width = (this._info.width.toString().match(/%/)) ? this._info.width : this._info.width+'px';
				var height = (this._info.height.toString().match(/%/)) ? this._info.height : this._info.height+'px';
				var epStyle="background:url('"+this._info.preview+"'); width:"+width+"; height:"+height+";";
				this.domNode.setAttribute('ep_style',epStyle);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.droplist"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.droplist"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.droplist");



epages.cartridges.de_epages.presentation.Droplist = function(opt) {
// summary: droplist constructor / initialize droplist
	this._setOptions(opt);

	var doc = document;

	// set up ghost
	this.ghostNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.ghostNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass : "Ghost";
	this.isGhostInList = false;

	// set up empty ghost
	this.emptyNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.emptyNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass+" Empty" : "Ghost Empty";
	this.emptyNode.appendChild(doc.createTextNode(this.options.listEmptyString));

	// set up new ghost
	this.newNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.newNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass+" New" : "Ghost New";
	this.newNode.innerHTML='<div class="ClickContainer"><div class="Container">'+this.options.addNewItemString+'</div></div>';
	if(this.options.newItemOnClick !== undefined) {
		this.newNode.firstChild.onclick = dojo.hitch(this, function() {
			dojo.publish("interactionRestrictor/suspend", ["newGhostRestrictor", this.newNode]);
			setTimeout(dojo.hitch(this, function() {
				this.options.newItemOnClick();
				setTimeout(function(){
					dojo.publish("interactionRestrictor/permit", ["newGhostRestrictor"])}, 400);
			}), 10);
		});
	}

	// dnd handler
	this.dndHandlerId=this.options.dndHandlerId;
	// listContainer
	this.listContainer = this.options.listContainer;
	this.sensitiveArea = (this.options.sensitiveArea) ? this.options.sensitiveArea : this.options.listContainer;

	this.listId=this.listContainer.id;

	// clean up list
	this._cleanUpList();

	// show empty Node
	this._insertEmptyGhost();

	// show new Node
	if(this.options.addNewItemString != ""){
		this._insertNewGhost();
	}

	// mark existing wrappers
	if(this.options.wrapperNodeName){
		this._markWrapper();
	}

	this._appendListeners();
};

epages.cartridges.de_epages.presentation.Droplist.prototype = {
	listContainer  : undefined,			// domnode   contains all the draggable nodes
	sensitiveArea  : undefined,			// domnode   draggables can be dropped inside the coordinates of this node
	listId         : undefined,			// string    id of listContainer node
	options        : undefined,			// object    options for constructor (see below)
	ghostNode      : undefined,			// domnode   node for dropghost
	isGhostInList  : undefined,			// boolean   indicates if the ghost / current drop target exsits in the list
	_isGhostSizeSet: undefined,			// boolean   inidcates if the ghost needs to be reszied / renderd again
	emptyNode      : undefined,			// domnode   will be inserted into empty list (show the user some text that he can insert something here)
	newNode        : undefined,			// domnode   add new item button

	_setOptions: function(options) {
		// summary: mix in options
		this.options = {
			// defaults
			dndHandlerId    : undefined,	// string    id of the main dnd handler (Dragdrop instance) / subscribe listeners to that id
			listContainer   : undefined,	// domnode   contains all the draggable nodes
			orientation     : undefined,  // string    orientation of list ("UpDown" or "LeftRight")
			wrapperNodeName : undefined,  // domnode   wrap dnd node nodename eg. div, td
			listEmptyString : '',					// string    this string will be inserted as text into empty node
			addNewItemString: '',					// string    this string will be used as label text for the emptyNode
			newItemOnClick  : undefined		// function  will be applied as click function on the newNode
		};
		dojo.mixin(this.options, options);
	},

	_appendListeners: function() {
	// summary: subscribe listeners to Dragdrop instance
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/move',  this, "_move");
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/drop',  this, "_drop");
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/start', this, "_startDragging");

		dojo.subscribe('droplist'+this.listId+'/change', this, "_listChange");
	},

	_isInsideSensitiveArea: function(/* object */ dndPos) {
	// summary: returns true if mouse coordinates are inside the sensitive area
		var containerElement = this.sensitiveArea;
		var listContPos = $E(containerElement).getAbsolutePosition();
		if(dndPos.mouseY >= listContPos.y && dndPos.mouseY <= listContPos.y + containerElement.clientHeight &&
			 dndPos.mouseX >= listContPos.x && dndPos.mouseX <= listContPos.x + containerElement.clientWidth) {
			return true;
		}else {
			return false;
		}
	},

	_canInsertBefore: function(/* domnode */ node, /* object */ dndPos) {
	// summary: returns true if an element can be inserted before
		var curPos = $E(node).getAbsolutePosition();
		if(this.options.orientation == "UpDown") {
			return (curPos.y > dndPos.mouseY);
		}else {
			return (curPos.x > dndPos.mouseX);
		}
	},

	_startDragging: function(opt) {
	// summary: event function dragrop/start - initaliaze dragging
		this._isGhostSizeSet = false;
		if(this._isInsideSensitiveArea(opt)) {
			opt.node.ep_droplistid = this.listId;
		}
	},

	_move: function(opt) {
	// summary: event function dragrop/move - show ghost
		if(this._isInsideSensitiveArea(opt)) {
			// position in list
			var node = this.listContainer.firstChild;
			while(node != null) {
				if(node.nodeType != 3 && opt.node !== node.firstChild && this._canInsertBefore(node,opt)) {
					break;
				}
				if(node.className == "Ghost New") {
					break;
				}
				node = node.nextSibling;
			}

			// set ghost
			if(!this._isGhostSizeSet) {
				this._setGhostSize(opt.node);
			}

			if(node != null) {
				this._insertGhostBefore(node);
			}else {
				this._insertGhostEol();
			}
		}else {
			this._removeGhost();
		}
	},

	_drop: function(opt) {
	// summary: event function dragrop/drop - finish dragging / publish drop in list event / insert node
		if(this.isGhostInList) {
			// find insertBefore node
			if(opt.element.onDropInList) {
				var insertBefore = null;
				if(this.options.wrapperNodeName) {
					if(this.ghostNode.nextSibling && this.ghostNode.nextSibling.firstChild && this.ghostNode.nextSibling.className != "Ghost New") {
						var insertBefore = this.ghostNode.nextSibling.firstChild;
						while(insertBefore != null && insertBefore.nodeType != 1) {
							insertBefore=insertBefore.nextSibling;
						}
						if(insertBefore.nodeType != 1)	{
							insertBefore = null;
							console.warn("Droplist._drop: no valid successor node found");
						}
					}
				} else {
					insertBefore = this.ghostNode.nextSibling;
				}

				// external handler
				opt.element.onDropInList({
					listObject: this,            // list object
					insertBefore: insertBefore,  // dom object or null
					oldWrapper: (opt.node.parentNode.ep_isWrapper) ? opt.node.parentNode : undefined,
					newWrapperNodeName: (this.options.wrapperNodeName) ? this.options.wrapperNodeName : undefined
				});
			} else {
				// standard handler
				this._insertNode(opt);
			}

			if(opt.node.ep_droplistid){
				dojo.publish('droplist'+opt.node.ep_droplistid+'/change', []);
			}

			//set reference to new list
			opt.node.ep_droplistid=this.listId;

			// remove ghost
			this._removeGhost();
			this._isGhostSizeSet=false;

			// remove empty Node
			this._removeEmptyGhost();
		}
	},

	_insertNode: function(/* object */ opt) {
	// summary: insert dragged node
		// save old wrapper
		var oldwrapper = (opt.node.parentNode.ep_isWrapper) ? opt.node.parentNode : undefined;

		// create new wrapper
		if(this.options.wrapperNodeName !== undefined) {
			var wrapperNode=this._createWrapper();
			this.listContainer.insertBefore(wrapperNode, this.ghostNode);
			wrapperNode.appendChild(opt.node);
		} else {
			this.listContainer.insertBefore(opt.node, this.ghostNode);
		}

		// remove old wrapper
		if(oldwrapper){
			this._removeWrapper(oldwrapper);
		}
	},

	_setGhostSize: function(/* domnode */ srcNode) {
	// summary: resize ghost node
		if(this.options.orientation == "UpDown") {
			this.ghostNode.style.width=this.listContainer.offsetWidth+"px";
			if(srcNode.clientHeight!=0 && srcNode.offsetHeight!="0"){
				this.ghostNode.style.height=srcNode.offsetHeight+"px";
			}else{
				this.ghostNode.style.height="27px";	// dirty fix for problem with dragelements whithout height (floated content)
			}
		} else {
			this.ghostNode.style.height=this.listContainer.offsetHeight+"px";
			this.ghostNode.style.width=srcNode.offsetWidth+"px";
		}
		this._isGhostSizeSet=true;
	},

	_insertGhostBefore: function(/* domnode */ node) {
	// summary: insert ghost node before a list element
		this.listContainer.insertBefore(this.ghostNode, node);
		this.isGhostInList = true;
		this._removeEmptyGhost();
	},

	_insertGhostEol: function() {
	// summary: insert ghost node before at the end of list
		this.listContainer.appendChild(this.ghostNode);
		this.isGhostInList = true;
		this._removeEmptyGhost();
	},

	_removeGhost: function() {
	// summary: remove ghostnode
		if(this.isGhostInList) {
			this.listContainer.removeChild(this.ghostNode);
			this.isGhostInList = false;
			this._insertEmptyGhost();
		}
	},

	_insertEmptyGhost: function() {
	// summary: show empty Node
		if(!this._hasElements()) {
			try {
				this.listContainer.appendChild(this.emptyNode);
			} catch(e) {
				// IE - can not add TD in an empty TR
				if (this.emptyNode.nodeName.match(/TD/i)) {
					var table = this.listContainer.parentNode.parentNode;
					table.outerHTML = table.outerHTML.replace(/<\/TR>/i, this.emptyNode.outerHTML + '$1');
				} else {
					new Error('droplist._insertEmptyGhost: could not append node, reason: ' + e.message);
				}
			}
		}
	},

	_insertNewGhost: function() {
	// summary: insert button for new items
		// show new Node
			try {
				this.listContainer.appendChild(this.newNode);
			} catch(e) {
				// IE - can not add TD in an empty TR
				if (this.emptyNode.nodeName.match(/TD/i)) {
					var table = this.listContainer.parentNode.parentNode;
					table.outerHTML = table.outerHTML.replace(/<\/TR>/i, this.emptyNode.outerHTML + '$1');
				} else {
					new Error('droplist._insertNewGhost: could not append node, reason: ' + e.message);
				}
			}
	},

	_removeEmptyGhost: function() {
	// summary: remove node with empty ghost (empty droplist hint)
		if(this._hasElements() && this.emptyNode.parentNode == this.listContainer){
			this.listContainer.removeChild(this.emptyNode);
		}
	},

	_createWrapper: function(/* domnode */ targetNode) {
	// summary: create a wrapper node
		var wrapper=document.createElement(this.options.wrapperNodeName);
		wrapper.className = "Wrapper";
		wrapper.ep_isWrapper = true;
		return wrapper;
	},

	_removeWrapper: function(/* domnode */ obj) {
	// summary: remove wrapper node
		obj.parentNode.removeChild(obj);
	},

	_markWrapper: function() {
	// summary: mark child nodes in listContainer as wrapper nodes
		var node = this.listContainer.firstChild;

		while(node != null) {
			if(node.nodeType == 1) {
				node.ep_isWrapper = true;
			}
			node=node.nextSibling;
		}
	},

	_listChange: function() {
	// summary: event function - droplist/change - update the emptyGhost
		if(!this._hasElements()) {
			this._insertEmptyGhost();
		}else {
			this._removeEmptyGhost();
		}
	},

	_cleanUpList: function() {
	// summary: remove all nodes which are no real nodes
			var node = this.listContainer.firstChild;
			while(node != null) {
				var deleteNode=undefined;
				if(node.nodeType != 1) {
					deleteNode = node;
				}
				node=node.nextSibling;
				if(deleteNode) {
					this.listContainer.removeChild(deleteNode);
				}
			}
	},

	_hasElements: function() {
	// summary: returns if childNodes exist
		return this.listContainer.hasChildNodes();
	}

};

}

if(!dojo._hasResource["epages.widget.Saveinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Saveinput"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Saveinput");



(function(dj){

	var _saveInput = {
		//paramString: '', // eg. "{ StyleName : 'MyDesign' }"
		buttonLabel : "",
		buttonNode : undefined,
		buttonWidget : undefined,
		previewNode : undefined,

		postCreate: function() {
		
			this.buttonLabel = 	this.domNode.getAttribute("buttonLabel") || "";
			this.url =			this.domNode.getAttribute("url") || "?";
			this.viewAction = 	this.domNode.getAttribute("viewAction") || "JSONViewResponse";
			this.changeAction =	this.domNode.getAttribute("changeAction") || "Save";
			this.objectId =		this.domNode.getAttribute("objectId") || '';
			this.attribute =	this.domNode.getAttribute("attribute") || '';
		
			// postMixInProperties
			this._request = dojo.fromJson(this.paramString) || {};
			this._request['ViewAction'] = this.viewAction;
			this._request['ChangeAction'] = this.changeAction;
			this._request['ObjectID'] = this.objectId;

			this.previewNode = document.createElement("span");
			this.previewNode.className = "SaveInputPreview ClickIcon";
			this.setPreviewContent();

			var bNode = document.createElement("input");
			bNode.type = "button";
			bNode.value= (this.buttonLabel != "") ? buttonLabel : this.dictionary.get("Save");
			dojo.addClass(this.domNode,"Saveinput");

			var nextSib = this.domNode.nextSibling;
			var parentNode = this.domNode.parentNode;

			if(nextSib) {
				parentNode.insertBefore(bNode,nextSib);
				parentNode.insertBefore(this.previewNode,nextSib);
			} else {
				parentNode.appendChild(bNode);
				parentNode.appendChild(this.previewNode);
			}
			this.buttonNode = bNode;

			var bWidget= new epages.widget.Button({},bNode);
			this.buttonWidget = bWidget;
			this.buttonWidget.hide();
			dojo.addClass(bWidget.domNode,"SaveinputButton");

			this.hideInput();

			this.connect(this.previewNode, "onclick", "showInput");
			this.connect(this.domNode, "onkeyup", "triggerButton");
			this.connect(bWidget.domNode, "onclick", "doSave");
		},
		
		_validate: function(){
			return true;
		},

		setPreviewContent : function() {
			this.previewNode.innerHTML = this.domNode.value+'<i class="Sprite ico_s_edit"></i>';
		},

		showInput: function(evt) {
			this.domNode.style.display="";
			this.previewNode.style.display="none";
		},

		hideInput: function(evt) {
			this.domNode.style.display="none";
			this.previewNode.style.display="";
		},

		triggerButton: function(evt) {
			this.buttonWidget.show();
			this.buttonWidget.enable();
			if(this.getValue() != this._lastErrorValue){
				this._removeError();
			}else{
				this._setError();
			}
			if(evt.keyCode === dojo.keys.ENTER){
				this.doSave();
			}
		},

		getValue: function() {
			return this.domNode.value;
		},

		doSave: function() {
			var v=this.getValue();
			this._request[this.attribute] = v;
			if(v) {
				this.buttonWidget.disable();
				var request = new epages.io.Json();

				request.loadAsync(this.url,
					epages.lang.hitch(this, function (result) { this.requestOk(result);}),
					this._request,
					epages.lang.hitch(this, function (result, data) { this.requestFailed(result, data);})
				);
			}
		},

		requestOk: function(result) {
			var v = this.getValue();
			if(result.error) {
				var errors = result.error.data.Errors;
				this._setError();
				this.domNode.focus();
				this._lastErrorValue=v;
				dojo.publish("uimessage/showErrorBubble",[
					this.dictionary.get('Error'),
					this.domNode,
					errors ,
					 (errors[0].Reason=="OBJECT_EXISTS") ? "Warning" : undefined]
				);
			} else {
				this.setStartUpValue(v);
				this._lastErrorValue=undefined;
				this.buttonWidget.hide();
				this._removeError();
				this.setPreviewContent();
				this.hideInput();
			}
		},

		requestFailed: function(result) {
			var errors = result.data.Errors;
			if(errors) {
				dojo.publish("uimessage/showErrors", [
					this.dictionary.get('Error'),
					this.dictionary.get('Save'),
					errors]
				);
			} else {
				var err= result.error[0];
				var errors = [{
						Message: err.message,
						Reason: err.error
				}];

				dojo.publish("uimessage/showErrors", [
					this.dictionary.get('Error'),
					this.dictionary.get('Save'),
					errors]
				);
			}
		},

		setStartUpValue: function( val ) {
			this.attr( 'startupValue', val );
			this.validate();
			
			return this;
		}
	};

	epages.widget.Saveinput = function( options, domNode ){
		this.destroy();
		
		var widget = new epages.widget.Validateinput( options, domNode );
		
			widget = dj.mixin( widget, _saveInput );
			
			widget.postCreate();

		return widget;
	};
	epages.widget.Saveinput.prototype = new dijit._Widget();


})(dojo);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolbox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolbox"] = true;
/*
	Copyright	(c)	2006-2007, epages	Software GmbH
	All	Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Toolbox	$Revision: 1.21 $

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolbox");




dojo.declare("epages.cartridges.de_epages.presentation.widget.Toolbox",
	[dijit._Widget, dijit._Templated, dijit._Container, dijit._Contained],
	{
		/**
		 * public properties
		 */
		caption				:	"",
		_menuWidget		: null,
		showCollectionName : '0',
		'class'       : '',

		/**
		 * public properties
		 */
		_lastSelectedMenuItem: null,
		_lastSelectedToolCollection: null,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolBox EnableHover\" id=\"${id}\" >\n  <div class=\"LayoutContainer\">\n    <div class=\"Body\" dojoAttachPoint=\"containerNode\"></div>\n    <div class=\"BoxTitle\"\n         dojoAttachPoint=\"boxTitleNode\"\n         dojoAttachEvent=\"onclick:showMenu\"\n         >\n      <span dojoAttachPoint=\"titleNode\">${caption}</span>\n      <span class=\"dijitInline dijitArrowNode dijitMenuExpandInner\">+</span>\n      <div class=\"Expander\">&nbsp;</div>\n    </div>\n  </div>\n</div>\n",
		imagePath:     epages.themeUrl('images'),

		// override
		startup:	function() {
                // summary: creates a menu of nested "Toolcollection" widgets
			this.inherited("startup", arguments);
			// add old classes
			dojo.addClass(this.domNode, this['class']);

			var childrenArray=this.getChildren();
			if(childrenArray.length>1) {
				this._menuWidget= new epages.widget.Menu();

				for(var	i=0,l=childrenArray.length; i<l; i++)	{
					if(childrenArray[i].declaredClass=="epages.cartridges.de_epages.presentation.widget.Toolcollection"){
						this._addRow(this.getChildren()[i]);
					}
				}
				dojo.addClass(this.boxTitleNode, "WithMenu");
			}

			if(childrenArray[0] !== undefined){
				this.switchTool(childrenArray[0], (this._menuWidget !== null && this._menuWidget.getChildren().length>0) ? this._menuWidget.getChildren()[0] : null);
			}
		},

		_addRow: function(/*Widget*/toolCollection) {
		// summary: add menu entry (link)
			var parentWidget=this;
			this._menuWidget.addChild(new dijit.MenuItem({
				label: toolCollection.caption,
				iconClass: 'MinimizeIcon',
				onClick: function() {
					parentWidget.switchTool(toolCollection, this);
				}
			}));
		},

		// menu / popup
		showMenu:	function()	{
		// summary: show menu
			dijit.popup.open({
				parent: this.domNode,
				popup : this._menuWidget,
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		},

		// event handler
		switchTool:	function(/* widget */toolCollection, /* widget */menuItem) {
                    	// summary: switch to the toolcollectio with the passed widgetid
			dijit.popup.close(this._menuWidget);
			if(this._lastSelectedMenuItem !== null){
				dojo.removeClass(this._lastSelectedMenuItem, "Selected");
			}
			if(this._lastSelectedToolCollection !== null){
				this._lastSelectedToolCollection.style.display="none";
			}

			// change toolbox title
			if(this.showCollectionName =='1') {
				var boxTitle=this.caption;
				boxTitle+=(toolCollection.caption!='' && this.caption !='') ? ":" : '';
				boxTitle+=toolCollection.caption;
				this.titleNode.innerHTML=boxTitle;
			}

			// show tool colection
			toolCollection.domNode.style.display="";
			// save selected toolcollection
			this._lastSelectedToolCollection=toolCollection.domNode;

			if(menuItem !== null) {
				// highlight menuitem (selected)
				dojo.addClass(menuItem.domNode, "Selected");
				// save selected menuItem
				this._lastSelectedMenuItem=menuItem.domNode;
			}
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcollection"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcollection"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolcollection");



dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Toolcollection",
	[epages.widget.TypedWidget, dijit._Contained],
	{
		/**
		 * public properties
		 */
		caption : "",

		/**
		 * widget properties
		 */
		templateType       : "table",
		defaultTemplateType: "table", // read-only!
		templateString:"<table class=\"ToolCollection\" id=\"${id}\" style=\"display:none\">\n  <tbody dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n",
		_templateMapping : {
			'table' : {templateString:"<table class=\"ToolCollection\" id=\"${id}\" style=\"display:none\">\n  <tbody dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n"},
			'div'   : {templateString:"<div class=\"ToolCollection\" id=\"${id}\" dojoAttachPoint=\"containerNode\" style=\"display:none\"></div>\n"}
		},

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.presentation.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimages"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimages"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolbuttonimages $Revision: 1.25 $

*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolbuttonimages");



dojo['require']("epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery");



dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbuttonimages",
	[epages.widget.LocalizedWidget], {
		/**
		 * public properties
		 */
		label						: "",
		fileNameLeft		: "",
		imageSetHidden	: "",
		imagesetLeft		: "",
		imagesetRight		: "",
		imageTiling			: "",
		imageType				: "",
		navBar					: "",
		objectId				: epages.vars.ObjectID,
		slaveWidgetId		: "",
		slaveWidget			: undefined,
		/**
		 * widget properties
		 */

		widgetType        : "Toolbuttonimages",
		templateString:"<tr class=\"ToolbackgroundImage LeftButton\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n    <div dojoAttachPoint=\"clearImageLeftNode\"\n          class=\"CommandSmallWithLink NoPadding\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat;\"\n          >{Delete}</div>\n\n    <input dojoAttachPoint=\"fileNameLeftNode\"\n           id=\"${navBar}${imageType}\"\n           name=\"${objectId}:${navBar}${imageType}\"\n           value=\"${fileNameLeft}\"\n           type=\"hidden\"\n           />\n\n    <div dojoAttachPoint=\"clearImageSetNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat; padding-left:18px;\"\n          >{ClearImageSet}</div>\n\n    <div dojoAttachPoint=\"restoreImageSetNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_redo.png) no-repeat;\"\n          >{RestoreImageSet}</div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageSetHiddenNode\"\n           id=\"${navBar}${imageType}Hidden\"\n           name=\"${objectId}:${navBar}${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${navBar}${imageType}\"\n           name=\"ImageSetLeft${navBar}${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input id=\"ImageSetRight${navBar}${imageType}\"\n           name=\"ImageSetRight${navBar}${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n\n    <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n         dojoAttachPoint=\"toolMediaGalleryWidget\"\n         multiSelect=\"false\"\n         validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n         opener=\"Toolbuttonimages\"\n         ></div>\n\n    <div dojoAttachPoint=\"tilingAreaNode\">\n      <input dojoAttachPoint=\"tilingCheckboxNode\"\n             name=\"TilingCheckBox\"\n             class=\"Checkbox\"\n             type=\"text\"\n             ep_noundo=\"1\"\n             />{Tiling}\n      <input dojoAttachPoint=\"imageTilingNode\"\n             type=\"hidden\"\n             name=\"${objectId}:${navBar}${imageType}Tiling\"\n             id=\"${navBar}${imageType}Tiling\"\n             value=\"${imageTiling}\" />\n    </div>\n  </td>\n</tr>\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate	: function() {
		 // summary: initalize file upload widget and other background image related events
			this.inherited("postCreate", arguments);

			// pass callback function to toolMediaGalleryWidget
			var me=this;
			this.toolMediaGalleryWidget.onApply = function(selectedElements) {
				if(selectedElements.length>0) {
					var pathFromSite=selectedElements[0].pathFromSite();
					if(pathFromSite!=null) {
						me.setFileName(pathFromSite);
					}
				}
			};

			this.tilingCheckboxNode = new epages.widget.FormElement({}, this.tilingCheckboxNode).elementNode;

			// init events
			this._appendEvents();
		},

		startup: function() {
			this.inherited("startup", arguments);
			if(this.slaveWidgetId != "") {
				this.slaveWidget=$$(this.slaveWidgetId);
				if(this.slaveWidget === undefined) {
					console.warn('SlaveWidget with id ="'+this.slaveWidgetId+'" not found in '+this.declaredClass);
				}
				else {
					dojo.subscribe(this.slaveWidgetId+'/filenamechanged', this, '_showButtons');
				}
			} else {
					console.warn('No slaveWidgetId in '+this.declaredClass+'. Slave functions will be ignored.');
				}

			// init buttons
			this._showButtons();
		},

		setFileName: function(pathFromSite){
			this.fileNameLeftNode.value = pathFromSite;
			epages.event.fire(this.fileNameLeftNode, "change");
		},

		/**
		 * private methods
		 */
		_appendEvents: function() {
		// summary: append onclick and onchange events to buttons and inputs

			// add button events
			this.connect(this.clearImageLeftNode,   'onclick', '_clearImageLeft');
			this.connect(this.clearImageSetNode,    'onclick', '_clearImageSet');
			this.connect(this.restoreImageSetNode,  'onclick', '_restoreImageSet');
			this.connect(this.tilingCheckboxNode,		'onclick', '_toggleImageTiling');

			// add input events (listen to value changes and update display)
			this.connect(this.fileNameLeftNode,			'onchange', '_showButtons');
			this.connect(this.imageSetHiddenNode,  	'onchange', '_showButtons');
			this.connect(this.imageTilingNode,  		'onchange', '_showButtons');
		},

		_clearImageLeft: function(evt) {
		// summary: clears the value of left image file name input and throw change event
			this.fileNameLeftNode.value="";
			epages.event.fire(this.fileNameLeftNode,"change");
		},

		_clearImageSet: function(evt) {
		// summary: set value of "imageSetHidden" input to "1" and throw change event
			this.imageSetHiddenNode.value="1";
			epages.event.fire(this.imageSetHiddenNode,"change");
		},

		_restoreImageSet: function(evt) {
		// summary: set value of "imageSetHidden" input to "0" and throw change events
			this.imageSetHiddenNode.value="0";
			epages.event.fire(this.imageSetHiddenNode,"change");	// trigger undo, redo for this element
			epages.event.fire(this.imageSetNode,"change");				// trigger style rule to display ImageSet images
		},

		_showButtons: function() {
		// summary: decides which button is visible

			if(this.imageTilingNode.value=='1') {
				this.tilingCheckboxNode.checked=true;			// Checkbox checked->true if value in hidden input=1. This happens if the user presses the undo or redo button
			}
			else {
				this.tilingCheckboxNode.checked=false;
			}

			var fileNameRightNodeValue= "";
			if(this.slaveWidget) {
				fileNameRightNodeValue= this.slaveWidget.getFileName();
			}

			if(this.fileNameLeftNode.value!="" || fileNameRightNodeValue!="" ) {
				if(this.fileNameLeftNode.value!="") {
				// show hide clear button left
					this.clearImageLeftNode.style.display="";
				} else {
					this.clearImageLeftNode.style.display="none";
				}

				if(this.fileNameLeftNode.value!='' && fileNameRightNodeValue=='') {
					this.tilingAreaNode.style.display="";		// (image tiling=yes) && (left image) && (no right image) --> show tiling checkbox |else --> hide tiling checkbox
				}
				else {
					this.tilingAreaNode.style.display="none";
				}

				// hide: clear imageset / restore imageset
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="none";
			} else if(this.imageSetHiddenNode.value!="1"){
				this.clearImageLeftNode.style.display="none";
				this.clearImageSetNode.style.display="";
				this.restoreImageSetNode.style.display="none";
				this.tilingAreaNode.style.display="none";
			}	else {
				this.clearImageLeftNode.style.display="none";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="";
				this.tilingAreaNode.style.display="none";
			}
		},

		_toggleImageTiling: function(evt) {
		// summary: hidden input / checkbox handler set
		// description: Handles the value of the hidden input element which depends on the visible checkbox.
		//		Afterwards it fires an change event to trigger the display handler (_showButtons).
			if(this.tilingCheckboxNode.checked==true) {
				this.imageTilingNode.value=1;
			} else {
				this.imageTilingNode.value=0;
			}
			epages.event.fire(this.imageTilingNode,"change");
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimageright"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimageright"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolbuttonimages $Revision: 1.14 $

*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolbuttonimageright");



epages.require('ep_shop_upload', 'epages.uploader');


dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbuttonimageright",
	[epages.widget.LocalizedWidget], {
		/**
		 * public properties
		 */
		label						: "",
		fileNameRight		: "",
		imageType				: "",
		objectId				: epages.vars.ObjectID,
		/**
		 * widget properties
		 */

		widgetType        : "Toolbuttonimageright",
		templateString:"<tr class=\"ToolbackgroundImage RightButton\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n    <input dojoAttachPoint=\"fileNameRightNode\"\n           id=\"${imageType}\"\n           name=\"${objectId}:${imageType}\"\n           value=\"${fileNameRight}\"\n           type=\"hidden\"\n           />\n\n    <div dojoAttachPoint=\"clearImageRightNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat;\"\n          >{Delete}</div>\n\n    <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n         dojoAttachPoint=\"toolMediaGalleryWidget\"\n         multiSelect=\"false\"\n         validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n         opener=\"Toolbuttonimageright\"\n         ></div>\n  </td>\n</tr>\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate	: function() {
		// summary: initalize file upload widget and other background image related events
			this.inherited("postCreate", arguments);

			// pass callback function to toolMediaGalleryWidget
			var me=this;
			this.toolMediaGalleryWidget.onApply = function(selectedElements) {
				if(selectedElements.length > 0) {
					var pathFromSite = selectedElements[0].pathFromSite();
					if(pathFromSite != null) {
						me.setFileName(pathFromSite);
					}
				}
			};

			// init events
			this._appendEvents();

			// init buttons
			this._showButtons();
		},

		getFileName: function() {
			return this.fileNameRightNode.value;
		},

		setFileName: function(pathFromSite){
			this.fileNameRightNode.value = pathFromSite;
			epages.event.fire(this.fileNameRightNode, "change");
		},

		/**
		 * private methods
		 */
		_appendEvents: function() {
		// summary: append onclick and onchange events to buttons and inputs

			// add button events
			this.connect(this.clearImageRightNode,  'onclick', '_clearImageRight');

			// add input events (listen to value changes and update display)
			this.connect(this.fileNameRightNode,		'onchange', '_showButtons');
		},

		_clearImageRight: function(evt) {
		// summary: clears the value of left image file name input and throw change event
			this.fileNameRightNode.value="";
			epages.event.fire(this.fileNameRightNode,"change");
		},

		_showButtons: function() {
		// summary: decides which button is visible
			dojo.publish(this.id+'/filenamechanged', [this.getFileName()]);
			if(this.fileNameRightNode.value!="") {
				this.clearImageRightNode.style.display="";			// show hide clear button right
			}
			else {
				this.clearImageRightNode.style.display="none";
			}
		}

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolsimpleinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolsimpleinput"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolsimpleinput $Revision: 1.20 $

*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolsimpleinput");




dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolsimpleinput",
	[epages.widget.LocalizedWidget, dijit._Container, dijit._Contained],
	{
		/**
		 * public properties
		 */
		label           : '',
		value           : '',
		inputType       : '',
		objectId        : '',
		lockLevel       : '', /* locklevel > 0 => attribute locked */
		validationType  : '',
		inputCssClass		: '',
		settings        : '',
		inputId         : '',
		customId        : true,
		/**
		 * widget properties
		 */
		templateString:"<tr>\n  <td class=\"InputLabelling\">${label}</td>\n  <td colspan=\"4\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"${validationType}\"\n           dojoAttachPoint=\"inputWidget\"\n           id=\"${inputId}\"\n           name=\"${objectId}:${inputType}\"\n           value=\"${value}\"\n           class=\"${inputCssClass}\"\n           type=\"text\"\n           settings=\"${settings}\"\n           />\n  </td>\n  <td></td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),
		widgetsInTemplate : true,

		postMixInProperties: function(){
			this.inherited("postMixInProperties", arguments);
			if(this.customId){
				this.inputId = this.inputType;
			}
		},

		// override
		postCreate  : function() {
			// summary: initalize widget
			// description: show lock icon and disable input field if locklevel is passed
			this.inherited("postCreate", arguments);
			if(this.lockLevel == '1' || this.lockLevel == '2') {
					this.inputWidget.domNode.disabled=true;
					this.domNode.className+=" disabled";
			}
		}
	});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolalignment"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolalignment"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolalignment $Revision: 1.8 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolalignment");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolalignment",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		alignment						: '',
		alignType						: '',
		objectId						: '',

		/**
		 * widget properties
		 */
		declaredClass		: 'epages.design.Toolalignment',
		templateString:"<tr>\n  <td class=\"InputLabelling NoWrap\">{Align}</td>\n  <td>\n    <select dojoAttachPoint=\"selectNode\"\n            name=\"${objectId}:${alignType}\"\n            id=\"${alignType}\"\n            class=\"SelectAlign\" >\n      <option value=\"left\"   >{AlignLeft}</option>\n      <option value=\"center\" >{AlignCenter}</option>\n      <option value=\"right\"  >{AlignRight}</option>\n    </select>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		// override
		postCreate	: function() {
                // summary: Set font select node value
			this.inherited("postCreate", arguments);
			this.selectWidget = new epages.widget.FormElement({}, this.selectNode);
			
			this.selectWidget.elementNode.value = this.alignment;
			this.selectWidget.elementNode.startupSelected = this.selectWidget.elementNode.selectedIndex;
			this.selectWidget.elementNode.startupIndex = this.selectWidget.elementNode.selectedIndex;
			this.selectWidget.elementNode.startupValue = this.selectWidget.elementNode.value;
			this.startUpChangeInterval = setInterval(dojo.hitch(this, function() {
				if(this.selectWidget.domNode.className.match("Changed")) {
					dojo.removeClass(this.selectWidget.domNode, "Changed");
					clearInterval(this.startUpChangeInterval);
				}
			}), 500);
		}
	});


}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarpreview"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarpreview"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Navbarpreview $Revision: 1.16 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navbarpreview");



dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navbarpreview",
	[epages.widget.LocalizedWidget,dijit._Contained],
	{
		/**
		 * public properties
		 */
		templateType: 'Layout1',
		defaultTemplateType: 'Layout1',

		_templateMapping:{
			'Layout1' : {templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"},
			'Layout2' : {templateString:"<div class=\"NavbarPreviewLayout2 ${cssClass}\">\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"},
			'Layout3' : {templateString:"<div class=\"NavbarPreviewLayout3 ${cssClass}\">\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div class=\"NavbarPreviewHeaderAndTop\">\n      <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n      <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n    </div>\n    <div class=\"NavbarPreviewBottomAndFooter\">\n      <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n      <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n    </div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n</div>\n"}
		},
		cssClass : '',
		visibleNavBars: undefined,

		/**
		 * widget properties
		 */
		imagePath       : epages.themeUrl('images'),
		templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		postCreate: function() {
			this.templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates');
			this.inherited('postCreate', arguments);
			this.visibleNavBars = epages.NavBars;
			if(this.visibleNavBars) {
				for(var el in this.visibleNavBars) {
					var navString=this.visibleNavBars[el][2];
					if(navString != "Delete") {
						this.enableBar(navString.toLowerCase());
						this.addNavbarEvents(navString, el);
					}
				}
			} else {
				console.warn("epages.NavBars not defined in "+this.declaredClass);
			}
		},

		addNavbarEvents : function(/* string */ navbar, /* string */ epObjectId) {
			var navbarlc = navbar.toLowerCase();
			var navbarNode = this[navbarlc + 'Node']
			navbarNode.ep_objectId = epObjectId;
			navbarNode.ep_navbar = navbar;
			this.connect(navbarNode, "onclick", '_publishSelect');
		},

		_publishSelect: function(evt) {
			var node = evt.currentTarget;
			dojo.stopEvent(evt);
			dojo.publish(this.id+'/select', [{ navbar: node.ep_navbar, objectId: node.ep_objectId }]);
		},

		enableBar: function (navbar) {
			this[navbar + 'Node'].style.display="";
		},

		disableBar: function (navbar) {
			this[navbar + 'Node'].style.display="none";
		},

		switchBar: function (navbar) {
			if (this[navbar + 'Node'].style.display=="none") {
				this.enableBar(navbar);
			} else {
				this.disableBar(navbar);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarselect"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarselect"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Navigationelement $Revision: 1.15 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navbarselect");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navbarselect",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		lockLevel:  			'0',
		layout:     			'Layout1',
		objectId:					'',
		undobuttonsId :		'undoWidget',

		headerIsVisible: 	'1',
		topIsVisible: 		'1',
		bottomIsVisible: 	'1',
		footerIsVisible: 	'1',
		leftIsVisible: 		'1',
		rightIsVisible: 	'1',

		/**
		 * private properties
		 */
		_dialogWidget: null,
		_dialogWidgetTarget: null,

		/**
		 * widget properties
		 */
		templateString:"<table><tr><td>\n  <input dojoAttachpoint=\"isVisibleHeaderNode\" type=\"hidden\" id=\"HeaderIsVisible\" name=\"${objectId}:HeaderIsVisible\" value=\"${headerIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleTopNode\" type=\"hidden\" id=\"TopIsVisible\"    name=\"${objectId}:TopIsVisible\"    value=\"${topIsVisible}\"    />\n  <input dojoAttachpoint=\"isVisibleBottomNode\" type=\"hidden\" id=\"BottomIsVisible\" name=\"${objectId}:BottomIsVisible\" value=\"${bottomIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleFooterNode\" type=\"hidden\" id=\"FooterIsVisible\" name=\"${objectId}:FooterIsVisible\" value=\"${footerIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleLeftNode\" type=\"hidden\" id=\"LeftIsVisible\"   name=\"${objectId}:LeftIsVisible\"   value=\"${leftIsVisible}\"   />\n  <input dojoAttachpoint=\"isVisibleRightNode\" type=\"hidden\" id=\"RightIsVisible\"  name=\"${objectId}:RightIsVisible\"  value=\"${rightIsVisible}\"  />\n  <div style=\"position:relative;top:-2px\">\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckHeaderIsVisible\" type=\"text\" value=\"Header\" ep_noundo=\"1\" /><label for=\"CheckHeaderIsVisible\">{NavbarHeader}</label></div>\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckTopIsVisible\"    type=\"text\" value=\"Top\" ep_noundo=\"1\" /><label for=\"CheckTopIsVisible\">{Top}</label></div>\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckBottomIsVisible\" type=\"text\" value=\"Bottom\" ep_noundo=\"1\" /><label for=\"CheckBottomIsVisible\">{Bottom}</label></div>\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckFooterIsVisible\" type=\"text\" value=\"Footer\" ep_noundo=\"1\" /><label for=\"CheckFooterIsVisible\">{NavbarFooter}</label></div>\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckLeftIsVisible\"  type=\"text\" value=\"Left\" ep_noundo=\"1\" /><label for=\"CheckLeftIsVisible\">{Left}</label></div>\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckRightIsVisible\" type=\"text\" value=\"Right\" ep_noundo=\"1\" /><label for=\"CheckRightIsVisible\">{Right}</label></div>\n  </div>\n</td>\n<td class=\"LeftPadding\">\n  <div dojoType=\"epages.cartridges.de_epages.design.widget.Navbarpreview\" dojoAttachpoint=\"Navbarpreview\"\n    layout=\"${layout}\"></div>\n</td></tr></table>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		widgetsInTemplate :true,

		// override
		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.lockLevel = parseInt(this.lockLevel);

			$A(['Header', 'Top', 'Left', 'Right', 'Bottom', 'Footer']).each( function (el) {
				var el_lc = el.toLowerCase();  // header
				var v = el_lc + 'IsVisible';   // attribute name: headerIsVisible
				var checkNode = $('Check' + el + 'IsVisible'); // checkHeaderNode
				var visibleNode = this['isVisible'+el+'Node']; // isVisibleHeaderNode
				var checkWidget = dijit.byNode(checkNode);
				this[v] = this[v] == '1' ? true : false;
				if (this.lockLevel > 0){
					 checkWidget.attr('disabled ',true);
				}
				// if (this._htmlUndo) this._htmlUndo.setDefaultValue(visibleNode);
				this.connect(checkNode,   'onclick', 'clickBar');
				this.connect(visibleNode, 'onchange', 'onChangeIsVisible');
				checkWidget.attr('checked',this[v]);
				if (this[v]) {
					this.Navbarpreview.enableBar(el_lc);
				} else {
					this.Navbarpreview.disableBar(el_lc);
				}
			}, this);
		},

		setBar: function (navbar, check) {
			$$('Check' + navbar + 'IsVisible').attr('checked',check);
			if (check) {
				this.Navbarpreview.enableBar(navbar.toLowerCase());
			} else {
				this.Navbarpreview.disableBar(navbar.toLowerCase());
			}
		},

		_createDialog: function(){

			var messageWidget = new epages.widget.Message({
				headline:this.translation.get("SaveQuestion"),
				message: this.translation.get("ChangeNavbarsDescription"),
				sizeClass:"Large",
				typeClass:"Warning"
			});

			var me =this;
			var buttons = [{
				label: this.translation.get("Save"),
				cssClass: 'Active',
				onclick: function() {
					this._modalDialogWidget.hide();
					me.sendChanges(me._dialogWidgetTarget);
				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					this._modalDialogWidget.hide();
					me._undoChange(me._dialogWidgetTarget);
				}
			}];
			this._dialogWidget = new epages.widget.Modaldialog({
				id: "Designtoolcontroller_DialogWidget",
				options:{
					title : this.translation.get("ChangeOnNavbars"),
					width : 400,
					height: 120,
					content: messageWidget
				},
				buttons : buttons

			});
			document.body.appendChild(this._dialogWidget.domNode);
		},

		sendChanges: function (t) {
			var navbar = t.value;
			var vNode = this['isVisible'+navbar+'Node'];
			vNode.value = t.checked ? '1' : '0';
			epages.event.fire(vNode,'change');
			if ($$(this.undobuttonsId)) {
				$$(this.undobuttonsId).sendChanges({
					text : this.translate("BusyWhileSavingData"),
					permanent : true
				});
				window.setTimeout(function(){
					window.location.href = window.location.href;
				},1000);
			}
		},

		clickBar: function (evt) {
			var u = $$(this.undobuttonsId);
			if(u){
				if(u.existsChanges()){
					if(!this._dialogWidget){
						 this._createDialog();
					}
					this._dialogWidgetTarget = evt.currentTarget;
					this._dialogWidget.show();
				} else{
					this.sendChanges(evt.currentTarget);
				}
			} else {
				this.sendChanges(evt.currentTarget);
			}
		},

		onChangeIsVisible: function (evt) {
			var t = evt.currentTarget;
			this.setBar(t.id.replace(/IsVisible$/, ''), t.value == '1' ? true : false);
		},

		_undoChange: function(t){
			t.checked = !t.checked;
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspacesheadline"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspacesheadline"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolspacesheadline $Revision: 1.4 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolspacesheadline");


dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolspacesheadline",
	[epages.widget.LocalizedWidget],
	{
		templateString:"<tr>\n  <td></td>\n  <td class=\"InputPadding\">{Top}</td>\n  <td class=\"InputPadding\">{Bottom}</td>\n  <td class=\"InputPadding\">{Left}</td>\n  <td class=\"InputPadding\">{Right}</td>\n  <td></td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget', 'templates/translation')
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspaces"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspaces"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolspaces $Revision: 1.20 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolspaces");




dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolspaces",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label           : '',
		top             : '',
		bottom          : '',
		left            : '',
		right           : '',
		spaceType       : '', /* Margin, Padding */
		objectId        : '',
		lockLevel       : '', /* locklevel > 0 => attribute locked */
		/**
		 * widget properties
		 */

		templateString:"<tr class=\"ToolSpaces\">\n  <td class=\"InputLabelling\">${label}</td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           dojoAttachPoint=\"topInputWidget\"\n           id=\"${spaceType}Top\"\n           name=\"${objectId}:${spaceType}Top\"\n           value=\"${top}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           dojoAttachPoint=\"bottomInputWidget\"\n           id=\"${spaceType}Bottom\"\n           name=\"${objectId}:${spaceType}Bottom\"\n           value=\"${bottom}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           dojoAttachPoint=\"leftInputWidget\"\n           id=\"${spaceType}Left\"\n           name=\"${objectId}:${spaceType}Left\"\n           value=\"${left}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           dojoAttachPoint=\"rightInputWidget\"\n           id=\"${spaceType}Right\"\n           name=\"${objectId}:${spaceType}Right\"\n           value=\"${right}\"\n           type=\"text\"\n           />\n  </td>\n  <td>\n      <img src=\"#System.StoreRoot/BO/icons/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" \n         dojoattachPoint=\"bubbleHelpPaddingNode\"\n         style=\"display: none\"/>\n       <span class=\"Tooltip ep-js\"  data-js=\"ep.uiTooltip({})\">\n        <div class=\"InfoPaddings\">\n          <div class=\"ExplainPaddings\">{ExplainPaddings}</div>\n            <div class=\"InfoPaddingsAdjustPosition\">\n              <div class=\"InfoPaddingsImageContainer\">\n                <img src=\"${imagePath}/infolayer_img_paddings.png\"\n                     alt=\"{ExplainPaddings}\"\n                     class=\"InfoPaddingsImage\" />\n                <div class=\"InfoPaddingsLabelTop\"   >{TopPadding}</div>\n                <div class=\"InfoPaddingsLabelLeft\"  >{LeftPadding}</div>\n                <div class=\"InfoPaddingsLabelBottom\">{BottomPadding}</div>\n                <div class=\"InfoPaddingsLabelRight\" >{RightPadding}</div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </span>\n\n      <img src=\"#System.StoreRoot/BO/icons/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" \n         dojoattachPoint=\"bubbleHelpMarginNode\"\n         style=\"display: none;\"/>\n       <span class=\"Tooltip Wide ep-js\"  data-js=\"ep.uiTooltip({})\">\n        <div class=\"InfoMargins\" >\n          <div class=\"ExplainMargins\">{ExplainMargins}</div>\n          <div class=\"InfoMarginsImageContainer\">\n            <img src=\"${imagePath}/infolayer_img_margins.png\"\n                 alt=\"{ExplainMargins}\"\n                 class=\"InfoMarginImage\" />\n            <div class=\"InfoText InfoMarginsLabelTop\"   >{TopMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelLeft\"  >{LeftMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelBottom\">{BottomMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelRight\" >{RightMargin}</div>\n          </div>\n        </div>\n      </tt>\n  </td>\n\n</tr>\n\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate  : function() {
                // summary: initalize widget
		// description: show lock icon and disable input fields if locklevel is passed
			if(this.spaceType.match("Margin")){
				this.bubbleHelpMarginNode.style.display="";
			}else if(this.spaceType.match("Padding")){
				this.bubbleHelpPaddingNode.style.display="";
			}
			this.inherited("postCreate", arguments);
			if(this.lockLevel == '1' || this.lockLevel == '2') {
					this.topInputWidget.domNode.disabled=true;
					this.bottomInputWidget.domNode.disabled=true;
					this.leftInputWidget.domNode.disabled=true;
					this.rightInputWidget.domNode.disabled=true;
					this.domNode.className+=" disabled";
			}
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfont"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfont"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolfont $Revision: 1.23 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolfont");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolfont",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label               : '',
		label_formatted     : '',
		size                : '',
		color               : '',
		isBold              : '',
		isItalic            : '',
		isUnderline         : '',
		isBoldInactive      : '',
		isItalicInactive    : '',
		isUnderlineInactive : '',
		isSizeInactive      : '',
		isSizeVisible       : '1',
		fontType            : '', /* Headline, Paragraph, Link, ... */
		objectId            : '',
		/**
		 * private properties
		 */
		_inputMapping   : undefined,
		_buttonMapping  : undefined,
		/**
		 * constants
		 */
		COLORPICKER_OFFSET_X: 18,
		COLORPICKER_OFFSET_Y: 0,
		/**
		 * widget properties
		 */
		declaredClass   : 'epages.design.Toolfont',
		templateString:"<tr class=\"Toolfont\">\n  <td class=\"InputLabelling NoWrap\"><span dojoAttachPoint=\"labelNode\">${label_formatted}</span></td>\n  <td class=\"FontSize\" dojoAttachPoint=\"fontSizeColumnNode\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           dojoAttachPoint=\"fontSizeWidget\"\n           class=\"FontSize FloatLeft\"\n           id=\"${fontType}Size\"\n           validationType=\"Size\"\n           name=\"${objectId}:${fontType}Size\"\n           value=\"${size}\"\n           type=\"text\" />\n  </td>\n  <td>\n    <div class=\"ButtonWrapper\">\n      <div dojoType=\"epages.cartridges.de_epages.presentation.widget.Toolcolor\"\n           color=\"${color}\"\n           colorType=\"${fontType}Color\"\n           objectId=\"${objectId}\"\n           templateType=\"colorbox\"\n           ></div>\n\n      <div dojoAttachPoint=\"boldDivNode\"\n           class=\"FontAttributeInactiveBox Bold\"\n           title=\"{Bold}\">{BoldAbbreviation}</div>\n      <input dojoAttachPoint=\"boldInputNode\"\n             id=\"${fontType}Bold\"\n             name=\"${objectId}:${fontType}Bold\"\n             value=\"${isBold}\"\n             type=\"hidden\" />\n\n      <div dojoAttachPoint=\"italicDivNode\"\n           class=\"FontAttributeInactiveBox Italic\"\n           title=\"{Italic}\">{ItalicAbbreviation}</div>\n      <input dojoAttachPoint=\"italicInputNode\"\n             id=\"${fontType}Italic\"\n             name=\"${objectId}:${fontType}Italic\"\n             value=\"${isItalic}\"\n             type=\"hidden\" />\n\n      <div dojoAttachPoint=\"underlineDivNode\"\n           class=\"FontAttributeInactiveBox Underline\"\n           title=\"{Underline}\">{UnderlineAbbreviation}</div>\n      <input dojoAttachPoint=\"underlineInputNode\"\n             id=\"${fontType}Underline\"\n             name=\"${objectId}:${fontType}Underline\"\n             value=\"${isUnderline}\"\n             type=\"hidden\" />\n    </div>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		widgetsInTemplate : true,

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			this.label_formatted = epages.format.slice(this.label, 15);
		},

		postCreate  : function() {
			// summary: Initialize widget: disable inactive buttons, set button state, add button events
			this.inherited("postCreate", arguments);

			this.boldDivNode.inputmappingkey='bold';
			this.italicDivNode.inputmappingkey='italic';
			this.underlineDivNode.inputmappingkey='underline';

			this._inputMapping = new epages.lang.Hash({
				bold     : this.boldInputNode,
				italic   : this.italicInputNode,
				underline: this.underlineInputNode
			});
			this._buttonMapping = new epages.lang.Hash({
				bold     : this.boldDivNode,
				italic   : this.italicDivNode,
				underline: this.underlineDivNode
			});

			if(this.label_formatted !== this.label){
				this.labelNode.title = this.label;
			}

			this._disableInactiveElements();
			this._displayButtonState();
			this._appendEvents();
		},

		/**
		 * private methods
		 */

		_appendEvents: function() {
		// summary: append events to buttons (bold, italic, underline)

			// add value handler
			this.connect(this.boldDivNode,      'onclick', '_toggleValue');
			this.connect(this.italicDivNode,    'onclick', '_toggleValue');
			this.connect(this.underlineDivNode, 'onclick', '_toggleValue');

			// add display handler
			this.connect(this.boldInputNode,      'onchange', '_displayButtonState');
			this.connect(this.italicInputNode,    'onchange', '_displayButtonState');
			this.connect(this.underlineInputNode, 'onchange', '_displayButtonState');
		},


		_disableInactiveElements: function() {
		// summary: disable inactive elements (buttons/inputfields)

			if(this.isSizeVisible=='0') {
				this.fontSizeColumnNode.style.display='none';
			}

			if(this.isSizeInactive=='1') {
				this.fontSizeWidget.domNode.style.display='none';
				this.fontSizeWidget.domNode.disabled=true;
			}
			if(this.isBoldInactive=='1') {
				this.boldDivNode.style.display='none';
				this.boldInputNode.disabled=true;
			}
			if(this.isItalicInactive=='1') {
				this.italicDivNode.style.display='none';
				this.italicInputNode.disabled=true;
			}
			if(this.isUnderlineInactive=='1') {
				this.underlineDivNode.style.display='none';
				this.underlineInputNode.disabled=true;
			}
		},

		_displayButtonState: function() {
		// summary: display button state (pressed, not pressed)

			var me=this;
			var Iterator = function(pair) {
				var ButtonInput=me._inputMapping.get(pair.key);
				var ButtonDiv=me._buttonMapping.get(pair.key);
				if(ButtonInput.value=='1') {
					ButtonDiv.className=ButtonDiv.className.replace('FontAttributeInactiveBox','FontAttributeBox');
				} else {
					ButtonDiv.className=ButtonDiv.className.replace('FontAttributeBox','FontAttributeInactiveBox');
				}
			};
			this._inputMapping.each(Iterator);
		},

		_toggleValue: function(/*Event*/evt) {
		// summary: event handler for button values (bold, italic, underline)
		// description: Toggles between values '0' and '1' of button input fields and throws an onchange event
		//    on the input field. (This triggers the display handler)

			var InputMappingKey=evt.currentTarget.inputmappingkey;
			var InputField=this._inputMapping.get(InputMappingKey);

			// toggle button value
			if(InputField.value=='1') {
				InputField.value='0';
			} else {
				InputField.value='1';
			}

			// throw change event on input field
			epages.event.fire(InputField,"change");
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.mcecontent']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.mcecontent'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.mcecontent $Revision: 1.57 $

*/
dojo.provide('epages.cartridges.de_epages.design.mcecontent');









epages.cartridges.de_epages.design.MceContent = epages.Class();

epages.cartridges.de_epages.design.MceContent.prototype = {
	/* constants */
	DIALOG_HEIGHT : "400",	// synchronized with .GadgetTable in BackOfficeStyle.css
	DIALOG_WIDTH  : "830",	// synchronized with .GadgetTable in BackOfficeStyle.css
	/* properties */
	navElementId: '',
	contentClass : 'epages.cartridges.de_epages.design.MceContent',
	base64 : new epages.string.Base64,
	preview: '', 						// path to the MBO preview images, e.g.: epages.vars.StoreRoot + '/BO/icons/content_ico_m_navelementgroup_flash.gif
	transparent: epages.vars.StoreRoot + '/BO/icons/general_img_transparentpixel.gif',
	dictionary : new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.design.widget', "templates/translation"),"auto"),
	title:  'content',
	width : 400,
	height: 400,
	doInsertDom: true,
	form     : undefined,
	group: null,
	formData : $H(),
	directPreview: true,

	initialize: function(options){
		this.save(options);
	},

	updateForm: function() {
		if (this.form !== undefined) {
			this.formData = $H(this.formData);
			(new epages.html.Form(this.form)).set(this.formData,true);
		}
	},

	saveForm: function() {
		if (this.form !== undefined){
			var formElements = this.form.elements;
			for( var i=0,iLength=formElements.length ; i<iLength ; i++ ){
				if(formElements[i].value){
					formElements[i].value = epages.validate.string.filterInvalidChars(formElements[i].value);
				}
			}
			this.formData = (new epages.html.Form(this.form)).get();
		}
	},

	save: function (options) {
		if (options !== undefined) {
			dojo.mixin(this, options);
			this.formData = $H(this.formData);
		}
	},

	info: function () {
		return {
			width        : this.width,
			height       : this.height,
			contentClass : this.contentClass,
			navElementId : this.navElementId,
			formData     : this.formData,
			preview      : this.preview,
			title        : this.title,
			group        : (epages.vars.externalcontent && epages.vars.externalcontent.currentGroupAlias) ? epages.vars.externalcontent.currentGroupAlias : '',
			autostart		 : this.autostart ? this.autostart : '',
			loop				 : this.loop ? this.loop : ''
		};
	},

	toString: function() {
		return "new " + this.contentClass + "(" + $H(this.info()).toString() + ")";
	},

	encodeInfo: function(info) {
		return this.base64.encode($H(info).toString());
	},

	decodeInfo: function(string) {
		var info = eval("(" + this.base64.decode(string) + ")");
		if (info.formData !== undefined){
			info.formData = $H(info.formData);
		}
		return info;
	},

	mceOpenWindow: function (editor_id, groupid) {
		var inst = tinyMCE.editors[editor_id];
		//var focusElm = inst.getFocusElement();
		var focusElm = inst.selection.getNode();

		var wrapper = null;
		// Is selection a image
		if (focusElm != null) {
			if (focusElm.nodeName.toLowerCase() == "img" && tinymce.DOM.getAttrib(focusElm, 'class').indexOf('epItemContent') > -1){
				wrapper = focusElm;
			}
		}

		var template = {};
		if (epages.vars.BaseUrl === undefined){
			epages.vars.BaseUrl = '';
		}
		template['url'] = epages.vars.BaseUrl +'?ViewAction=MBO-ViewPluginEpContent&ObjectID=' + epages.vars.ObjectID;
		if (epages.vars.DefaultParams != null){
			template['url'] += epages.vars.DefaultParams;
		}
		if (wrapper != null) {
		  var ep_info = tinymce.DOM.getAttrib(wrapper, 'ep_info');
			template['url'] += '&ContentData=' + ep_info;
			var navElementId = (this.decodeInfo(ep_info)).navElementId;
			if (navElementId !== undefined){
			  template['url'] += '&NavElementID=' + navElementId;
			}
		}
		if (groupid != null){
			template['url'] += '&GroupID=' + groupid;
		}

		template['width']  = this.DIALOG_WIDTH;
		template['height'] = this.DIALOG_HEIGHT;
		template['scrollbars'] = "yes";
		template['resizable'] = "yes";
		template['title'] = this.dictionary.get("InsertGadget");

		inst.windowManager.open(template, {editor_id : editor_id, inline : "yes", mce_replacevariables:false });
	},

	contentString: function(info) {
		return ['<img src="' + info.preview,
			'width="'  + info.width,
			'height="' + info.height,
			'alt="'    + this.title,
			'title="'  + this.title,
			'/>'
		].join('" ');
	},

	previewString: function(info) {
		var width = (info.width.toString().match(/%/)) ? info.width : info.width+'px';
		var height = (info.height.toString().match(/%/)) ? info.height : info.height+'px';
		return ['<img class="epItemContent',
			'src="' + this.transparent,
			'style="background-image: url('+ info.preview+');height:'+height+'; width:'+width+';"',
			'ep_style="background-image: url('+ info.preview+');height:'+height+'; width:'+width+';"',
			'width="'  + info.width,
			'height="' + info.height,
			'alt="'  + this.title,
			'title="'  + this.title,
			'ep_info="' + this.encodeInfo(info),
			'ep_dom="' + (this.doInsertDom ? 'true' : 'false'),
			'ep_group="' + info.group,
			'/>'
		].join('" ');
	},

	mceInsertContent: function (info) {
		if (info === undefined){
			info = this.info();
		}
		if (typeof (window.ep_InsertContent) == 'function') {
			window.ep_InsertContent(this,info);
		} else {
			var html = this.previewString(info);
			//go back to saved bookmark necessary for ie
			tinyMCE.activeEditor.selection.moveToBookmark(tinymce.WindowManager.bookmark);
			tinyMCE.execCommand("mceInsertContent", true, html);
		}
	},

	parseAttributes : function (string) {
		if (string == null || string.length < 2){
			return {};
		}

		var attributeName = "";
		var attributeValue = "";
		var attributes = {};
		var whiteSpaceRegExp = new RegExp('^[ \n\r\t]+', 'g');

		var withInName = false, withInValue = false;

		for( var i=0,iLength=string.length ; i<iLength ; i++ ) {
			var chr = string.charAt(i);

			if ((chr == '"' || chr == "'") && !withInValue){
				withInValue = true;
			}else if ((chr == '"' || chr == "'") && withInValue) {
				withInValue = false;

				var pos = attributeName.lastIndexOf(' ');
				if (pos != -1){
					attributeName = attributeName.substring(pos+1);
				}

				attributes[attributeName.toLowerCase()] = attributeValue.substring(1);

				attributeName = "";
				attributeValue = "";
			} else if (!whiteSpaceRegExp.test(chr) && !withInName && !withInValue){
				withInName = true;
			}
			if (chr == '=' && withInName){
				withInName = false;
			}
			if (withInName){
				attributeName  += chr;
			}
			if (withInValue){
				attributeValue += chr;
			}
		}

		return attributes;
	},

	mceEditor2String: function (/*String*/content) {
		// replace preview images with epItemContent divs
		var startPos = -1;
		while ((startPos = content.indexOf('<img', startPos+1)) != -1) {
			var endPos = content.indexOf('>', startPos) + 1;
			var attributesString = content.substring(startPos + 4, endPos);
			var attribs = this.parseAttributes(attributesString);
			if (attribs['class'] == "epItemContent") {
				// replace
				var start = content.substring(0, startPos);
				var end   = content.substring(endPos);
				var old   = content.substring(startPos, endPos);
				var info = this.decodeInfo(attribs['ep_info']);
				var object = epages.cartridges.de_epages.design.MceContent.prototype.LOAD(info);
				if (object !== undefined) {
					// ATTENTION: do not change the order of these attributes
					var newString = '<!-- BEGIN_GADGET -->\n<div class="epItemContent ep_info:' + attribs['ep_info'] + '">' + object.contentString(info) + '<'+'/div>\n<!-- END_GADGET -->';
					content = start + newString + end;
				} else {
					startPos = endPos;
				}
			} else {
				startPos = endPos;
			}
		}
		return content; //String
	},

	load: function (domObject) {
		domObject.innerHTML = this.contentString(this.info(), false);
	},

	getIframeDocument: function (domObject) {
		return $E(domObject).getIframeDocument();
	},

	loadPreview: function (domObject) {
		var iframeDoc = this.getIframeDocument(domObject),
			iframeWin = iframeDoc.defaultView,
			bodyNode = iframeDoc.getElementsByTagName('body')[0],
			scriptType,
			scriptContent,
			scripts,
			script;

		if( bodyNode && iframeWin ){
			bodyNode.innerHTML = this.contentString(this.info(), true);

			scripts = bodyNode.getElementsByTagName('script') || [];

			for( var i=0,iLength=scripts.length ; i<iLength ; i++ ){
				script = scripts[i];
				scriptType = dojo.attr( script, 'type' );
				if( !scriptType || /javascript/i.test(scriptType) ){
					scriptContent = script.innerHTML;
					if( scriptContent && /\S/.test( scriptContent ) ){
						(function( scriptContent ){
							var window = iframeWin,
								document = window.document;
							iframeWin['eval'].call( iframeWin, scriptContent );
						})( scriptContent );
					}
				}
			}
		}
		else{
			console.warn('loadPreview: ' + ( iframeWin ? 'iframe body' : 'window object of iframe' ) + ' not found in epages.cartridges.de_epages.design.MceContent');
		}
	},

	saveFormAndLoadPreview: function (domObject) {
		this.saveForm();
		this.loadPreview(domObject);
	},

	saveFormAndMceInsertContent: function () {
		this.saveForm();
		this.mceInsertContent();
	},

	LOAD: function(options) {
		if (options.contentClass === undefined || options.contentClass == '') {
			console.error('cant load object without contentClass.');
			return undefined;
		}
		if (window[options.contentClass] === undefined){
			dojo["require"](options.contentClass.toLowerCase());
		}
		var obj = new(eval(options.contentClass))(options);
		return obj;
	},

	string2Preview:function(content){
		//summary: replace Gadget with place holder for editing
		//regular Expression to find ep_info on old gadget where ep_info was an attribute and on new gadget where ep_info is inside style attribute
		var epInfoRegEx = new RegExp ("<!--\\s*BEGIN_GADGET\\s*-->[\\s\\S]*?<div\\s+(class=\"epItemContent\"\\s+ep_info=\"|class=\"epItemContent ep_info:)(.+?)\"?>[\\s\\S]*?<!--\\s*END_GADGET\\s*-->","mig");
		var regExResult;
		var resultContent = content;
		// while-loop is necessary to find all gadgets inside the content string regExp-object uses internal method do find the next match
		// so we habe to do it till we find the last match
		while((regExResult = epInfoRegEx.exec(content))){
			if(regExResult && regExResult[2]){ //check if new ep_info was found
				var decodedInfo = this.decodeInfo(regExResult[2]);
				var gadgetObject = epages.cartridges.de_epages.design.MceContent.prototype.LOAD(decodedInfo);
				var replaceContent = gadgetObject.previewString(decodedInfo);
				//need  copy of content for correct working RegExp-object while looping through all gadgets inside content
				//replace gadget with preview image
				resultContent = resultContent.replace(regExResult[0],replaceContent);
			}
		}
		return resultContent;
	}
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navigationelement"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navigationelement"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Navigationelement $Revision: 1.65.10.1 $

*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navigationelement");














epages.cartridges.de_epages.design.widget.Navigation = {
	dndHandler        : undefined,	// epages.cartridges.de_epages.presentation.dragdrop - drag and dro handler

	createElement : function (/*String*/navElementId, /*String*/styleId, /*String*/navBarAlias, /*String*/url) {
		// summary:
		//			function to create a new widget
		// description:
		//			load template snippet, initalizes and insert the widget
		// navElementId:
		//			navigation element type id
		// styleId:
		//			ObjectID of current style
		// navBarAlias:
		//			alias of navbar e.g. "Right"
		// url:
		//			request url (default is '?')
		if (url === undefined){
			url = '?';
		}
		var j = new epages.io.Json();
		var output = j.loadSync(url, {
			ChangeAction: 'AddNavElement',
			ChangeObjectID: styleId,
			NavElementID: navElementId,
			NavBarAlias: navBarAlias,
			ViewAction: 'JSONNavBarElementSnippet',
			IsEditorNavElements: 1,
			IsEditorModeEnabled: 1
		});
		if(output.error){
			if(output.error.data && output.error.data.Errors) {
				//highjack translations
				hl = epages.cartridges.de_epages.design.widget.Navigationelement.prototype.translate("ErrorCreateNewPageElement");
				tb = epages.cartridges.de_epages.design.widget.Navigationelement.prototype.translate("CreateNewPageElement");
				dojo.publish("uimessage/showErrors", [hl, tb,	output.error.data.Errors]);
			}
			return false;
		}	else if(output.data){
			var navbar = epages.NavBars[output.data.navbarid][3];
			var doc = navbar.ownerDocument;
			var e = doc.createElement("div");
			e.innerHTML = output.data.snippet;
			e.id = 'Element' + output.data.id;
			epages.html.disableHrefsAndActions(e);

			epages.cartridges.de_epages.design.widget.Navigation.getNavBarDelete(doc).appendChild(e);
			var win = (doc.parentWindow) ? doc.parentWindow : doc.defaultView;

			var widgetClass = 'epages.cartridges.de_epages.design.widget.Navigationelement';

			if(win.epages.vars.NavigationElementWidgetTypes) {
				if(win.epages.vars.NavigationElementWidgetTypes[navElementId]) {
					widgetClass = win.epages.vars.NavigationElementWidgetTypes[navElementId];			//catch widget type
					win.dojo["require"](widgetClass);
				}
			}
			widgetClass='win.'+widgetClass;

			var w = new(eval(widgetClass))({
				elementId: e.id,
				objectId: output.data.id,
				navbar: 'Delete',
				isCustomizable: output.data.isCustomizable,
				position: output.data.position,
				doc : doc
			});
			w.setNavBar(output.data.navbarid);
			return w;
		}
	},
	getNavBarDelete: function( doc ){
		var node = this.getNavBarDelete.node || ( this.getNavBarDelete.node = $('NavBarDelete',doc) );

		if ( !node ) {
			node = this.getNavBarDelete.node = doc.createElement("div");

			node.id = 'NavBarDelete';
			node.style.display = 'none';

			doc.getElementsByTagName("body")[0].appendChild(node);
		}

		return node;
	}
};

dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navigationelement",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		objectId            : '',           // String - epages objectid of navigation element
		position            : '',           // String - current position in navbar
		navbar              : '',           // String - current navbar identifier
		orientation         : '',           // String - current navbar orientation e.g. UpDown
		elementId           : '',           // String - id of the navigationelement domnode
		storeRoot           : epages.vars.StoreRoot,	// [readonly] String - epages store root path
		undoWidgetId        : 'undoWidget', // String - id of undo widget
		isCustomizable      : '',           // Boolean - indicates weather the navigation element has an edit dialog or not
		url                 : '?',          // String - request url string
		languageId          : epages.vars.Locale.languageId,  // string - current language id
		emptyString         : '',           // String - will be displayed in empty customizable html areas
		doc                 : undefined,    // document - navigation elements document
		reloadOnOrientationChange: false,   // Boolean - indicates weather the html code of an navigation element needs to be reloaded after changing the navbar (some navigation elements use a different html code base for navigation bars with different orientations)
		nameOrAlias         : "",           // String - #NameOrAlias
		_widgetsA           : [],           // Array - list of navelement widgets for each navbar (prototype Array)
		_htmlUndo           : undefined,    // epages.cartridges.de_epages.presentation.widget.Undobuttons - html undo object to register changes
		_inputs             : undefined,    // domnode[] - list of editor inputs in edit dialog (name starts with editor_)
		positionNode        :   undefined,  // domnode - input field to enable undo for position
		navbarChangeNode    : undefined,    // domnode  - input field to enable undo for navbar
		navElementNode      : undefined,    // domnode - node of the original navigation element
		_navElementNodeCache: undefined,    // hash - caches elementnodes for different navelement views (UpDown/LeftRight)
		_deleteConfirmation : false,        // [readonly] Boolean - flag that indicates weather the delete confirmation dialog will be shown or not (flag source: top.epages.vars.SessionUserDeleteConfirmation)

		/**
		 * widget properties
		 */
		imagePath       : epages.themeUrl('images'),   // String - path to widget image folder
		templateString:"<div style=\"position: relative;\" class=\"NavigationElementWidget\">\n  <div dojoAttachPoint=\"contentNode\"><div dojoAttachPoint=\"replaceNode\"></div></div>\n  <div class=\"ButtonsAndMetainfo\" dojoAttachEvent=\"mouseenter:mouseenter_ButtonAndMetainfo,mouseleave:mouseleave_ButtonAndMetainfo\"><div class=\"Container\">\n    <i dojoAttachPoint=\"deleteNode\" class=\"DeleteNode Sprite ico_s_delete\" title=\"{Delete}\"></i>\n    <i dojoAttachPoint=\"editNode\" class=\"EditNode Sprite ico_s_edit\" title=\"{Edit}\"></i>\n    <span dojoAttachPoint=\"dndNode\"\n         title=\"{Move}\"\n         class=\"DndNode\"\n         ></span>\n  </div></div>\n</div>\n", // String - path to widget template
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'), // String - path to widget translation

		loadNavBarElement : function (navElementId, styleId, navBarAlias, url) {
		// summary: get and insert navbar element snippet
			if (url === undefined){
				url = '?';
			}
			var j = new epages.io.Json();
			var output = j.loadSync(url, {
				ObjectID: styleId,
				NavElementID: navElementId,
				NavBarAlias: navBarAlias,
				ViewAction: 'JSONNavBarElementSnippet',
				IsEditorNavElements: 1,
				IsEditorModeEnabled: 1
			});

			if(output.error){
				return false;
			} else if(output.data){
				var navbar = epages.NavBars[output.data.navbarid][3];
				var doc = navbar.ownerDocument;
				var e = doc.createElement("div");
				e.innerHTML = output.data.snippet;
				e.id = 'Element' + output.data.id;
				epages.html.disableHrefsAndActions(e);
				return e;
			}
		},

		elementNode : function () {
			// summary:
			//			returns the element domnode which will be moved via dnd
			// description:
			//   		the domnode that will be moved can be the widgets root dom
			//			node or the parent node of the dom node (td-tag)
			return this.orientation == 'UpDown' ? this.domNode : this.domNode.parentNode;		// dom node
		},

		navbarNode : function () {
			// summary:
			//			returns the container node for dnd elements
			return this.elementNode().parentNode;
		},

		elementNodes: function () {
			// summary:
			//			returns all draggable nodes in the current navigation bar
			return dojo.filter(this.navbarNode().childNodes, function (el) { // DomNode[]
				return el.nodeType == 1;
			});
		},

		currentIndex: function () {
			// summary: returns the navigation bar index of the element
			return $A(this._widgetsA[this.navbar]).find(this); // Integer
		},

		existsPosition: function (/*integer*/ position, /*integer*/ navbarid) {
		// summary: check weather the specified position exits in specified navbar
			if (navbarid === undefined){
				navbarid = this.navbar;
			}
			var a = $A(this._widgetsA[navbarid]).grep(function (el) {
				return parseInt(el.positionNode.value) == position; // Boolean
			});
			return a.length > 0; // Boolean
		},

		postMixInProperties: function() {
		// summary: prepare defaults
			this.inherited("postMixInProperties", arguments);
			if(this.doc === undefined || this.doc == ''){
				this.doc = document;
			}
			if (typeof this.isCustomizable == 'string') {
				this.isCustomizable = epages.string.toBoolean(this.isCustomizable);
			} else {
				this.isCustomizable = this.isCustomizable == 0 ? false : true;
			}
			this._inputs = [];
			this.emptyString = '- '+this.translate('ClickToChangeContent')+' -';
			if(top.epages.vars.SessionUserDeleteConfirmation == 1){
				this._deleteConfirmation = true;
			}
		},

		postCreate  : function() {
			// summary:
			//			prepare navelement widget nodes / events / ...
			this.inherited("postCreate", arguments);

			this.positionNode = this.doc.createElement("input");
			this.positionNode.type  = 'hidden';
			this.positionNode.name  = this.objectId + ':Position';
			this.positionNode.value = this.position;

			this.navbarChangeNode = this.doc.createElement("input");
			this.navbarChangeNode.type  = 'hidden';
			this.navbarChangeNode.name  = this.objectId + ':NavBar';
			this.navbarChangeNode.value = this.navbar;

			// IE fix onchange event
			if (epages.Browser.engine == 'MSIE') {
				this.doc.getElementsByTagName('body')[0].appendChild(this.positionNode);
				this.doc.getElementsByTagName('body')[0].appendChild(this.navbarChangeNode);
			}

			epages.cartridges.de_epages.design.widget.Navigation.getNavBarDelete(this.doc);

			if (epages.NavBars !== undefined) {
				epages.NavBars['Delete'] = ['Delete', 'UpDown', 'Delete'];
			}
			if (!this.isCustomizable){
				this.editNode.style.display = 'none';
			}

			// get undo object for add inputs
			if (this._htmlUndo === undefined) {
				var undoWidget = $$(this.undoWidgetId);
				if (undoWidget === undefined) {
					console.warn('undo widget not found in '+this.declaredClass +'. (undoWidgetId = ' + this.undoWidgetId + ')');
				} else {
					this._htmlUndo = undoWidget.getUndoObject();
				}
			}

			// move navelement in my widget
			var element = $(this.elementId,this.doc);
			if (element) {
				$E(this.replaceNode.parentNode).replaceChild(element,this.replaceNode);
			} else {
				console.warn("widget Navigationelement can't find element:" + this.elementId);
			}

			var child = element.firstChild;
			while(child != null && this.navElementNode === undefined) {
				if(child.nodeType==1) {
					this.navElementNode = child;
				}
				child=child.nextSibling;
			}
			if(this.navElementNode){
				this._adjustGeomtry(this.navElementNode);
			}

			// initialize navbar
			if (this._widgetsA[this.navbar] === undefined){
				this._widgetsA[this.navbar] = [];
			}
			this._widgetsA[this.navbar].push(this);

			if (this._htmlUndo) {
				this._htmlUndo.setDefaultValue(this.positionNode);
				this._htmlUndo.setDefaultValue(this.navbarChangeNode);
			}

			// add global drag and drop handler if it isn't already added
			if(epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler === undefined) {
				epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler=$DND("NavElements", [], $('Content'));
			}

			var win = (this.doc.parentWindow) ? this.doc.parentWindow : this.doc.defaultView;

			var dndHandler = win.epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler;
			// register widget as drag and drop element
			dndHandler.addElement({
				clickNode: this.dndNode,
				moveNode: this.domNode,
				widget: this,
				onDropInList: function(opt) {
					this.widget.onDropInList(opt);
				},
				forceSize: true
			});

			// connect events
			this.connect(this.deleteNode, 'onclick', 'onclickDeleteNode');
			if (this.isCustomizable){
				this.connect(this.editNode, 'onclick', 'onclickEditNode');
			}

			if (epages.NavBars !== undefined) {
				this.connect(this.navbarChangeNode, 'onchange', 'onchangeNavbarChangeNode');
				this.orientation = epages.NavBars[this.navbar][1];
			}

			// prepare for orientation change (differnet views of some navelements)
			this.reloadOnOrientationChange = (this.navElementNode && this.navElementNode.className.match("ReloadOnOrientationChange")) ? true : false;
			this._navElementNodeCache = $H();
			this._navElementNodeCache.set(this.orientation, this.navElementNode);
			this.connect(this.positionNode, 'onchange', 'onchangePositionNode');
		},

		setNodePosition: function (position) {
			// summary:
			//			set new position
			this.positionNode.value = position;
			if (this._htmlUndo){
				this._htmlUndo.addInput(this.positionNode);
			}
		},

		onchangePositionNode: function (evt) {
			// summary:
			//			called when position node fired a change / adjusts _widgetsA
			//			and dom node postion
			// tags:
			//			callback
			dojo.stopEvent(evt);

			// remove current (changed)
			var position = parseInt(this.positionNode.value);
			var waArray = $A(this._widgetsA[this.navbar]);
			var oldlength = waArray.length;
			waArray.remove(waArray.find(this));

			// add changed on right place
			var wa = waArray.grep(function (el) {
				return parseInt(el.positionNode.value) <= position;
			}).concat(this, waArray.grep(function (el) {
				return parseInt(el.positionNode.value) > position;
			}));
			if (oldlength != wa.length){
				console.warn('Widget Navigationelement list changed!! oldlength:' + oldlength +'!= new length:'+ wa.length);
			}
			this._widgetsA[this.navbar] = wa;

			// correct dom nodes
			for( var i=0,l=wa.length ; i<l ; i++ ) {
				wa[i].navbarNode().appendChild(wa[i].elementNode());
				// renumber classnames
				var className = wa[i].navElementNode.className;
				var className = className.replace(/NavBarElement\d*/,"NavBarElement"+i);
				wa[i].navElementNode.className = className;
			}

			this.adjustNewGhostEol();
		},

		onclickDeleteNode: function (evt) {
		// summary:
		//			called when delete node was clicked / shows a delete confirmation dialog
		// tags:
		//			callback
			dojo.stopEvent(evt);
			if(this._deleteConfirmation){
				var me = this;
				epages.topDojo.publish("uimessage/show", [ this.translate('AcceptDeletePageElement'), "", 'Dialog', {
					titleBar: this.translate('DeletePageElement'),
					typeClass: 'Confirmation',
					buttons: [{
						label: '{Delete}',
						cssClass: 'Active',
						onclick: function() {
							me.deleteNavigationElement();
							this._modalDialogWidget.hide();
						}
					},{
						label: '{Cancel}',
						onclick: function() { this._modalDialogWidget.hide(); }
					}]
				}
				]);
			}	else {
				this.deleteNavigationElement();
			}
		},

		deleteNavigationElement: function(){
		// summary:
		//			move navigation element into delete navigation bar
			this.setNavBar('Delete', false);
			dojo.publish("Navigationelement/DeleteFinished", []);
		},

		setNavBar: function (navbarid, pushOnEnd, orientation) {
		// summary:
		//			move navigation element into specified navigation bar
			if (this.navbar == navbarid){
				return;
			}
			if (pushOnEnd === undefined){
				pushOnEnd = true;
			}
			if (epages.NavBars !== undefined) {
				orientation = epages.NavBars[navbarid][1];
			}

			// reload element view for different orient (if necessary)
			if(orientation !== this.orientation && this.reloadOnOrientationChange) {
				var el = this._navElementNodeCache.get(orientation);
				if(el === undefined) {
					el = this.loadNavBarElement(this.elementId, this.objectId, epages.NavBars[navbarid][2]);
					if(el !== false){
						// chache element
						this._navElementNodeCache.set(orientation, el);
					}else{
						console.warn('Could not load different view of navigation element');
					}
				}
				// replace domnode
				this.navElementNode.parentNode.replaceChild(el, this.navElementNode);
				// assign new domnode to object property
				this.navElementNode = el;
			}

			var navbar = $('NavBar' + navbarid,this.doc);
			if (navbar == null) {
				console.error('Element NavBar' + navbarid + ' not found.');
				return;
			}
			// add to new list
			if (this._widgetsA[navbarid] === undefined){
				this._widgetsA[navbarid] = [];
			}
			var wa = this._widgetsA[navbarid];
			var position = parseInt(this.positionNode.value);
			var positionChanged = false;
			if (wa.length) {
				if (!pushOnEnd && this.existsPosition(position, navbarid)){
					pushOnEnd = true;
				}
				if (pushOnEnd) {
					var i = wa.length;
					var last = wa[i - 1];
					var lastPos = parseInt(last.positionNode.value);
					if (position <= lastPos) {
						position = lastPos + 10;
						positionChanged = true;
					}
				}
			}
			// change dom nodes
			if (this.orientation == orientation) {
				$E(navbar).appendChild(this.elementNode());
			} else {
				if (orientation == 'LeftRight') {
					// move from div to tr (add td)
					var td = this.doc.createElement('td');
					$E(navbar).appendChild(td);
					td.appendChild(this.elementNode());
				} else {
					// move from tr to div (remove td)
					var td = this.elementNode();
					$E(navbar).appendChild(this.domNode);
					td.parentNode.removeChild(td);
				}
				this.orientation = orientation;
			}
			if (positionChanged){
				this.positionNode.value = position;
			}
			this.navbarChangeNode.value = navbarid;

			// remove from old list and add to new
			var waOld = this._widgetsA[this.navbar];
			waOld.splice($A(waOld).find(this), 1);
			wa.push(this);
			this.navbar = navbarid;


			if(!pushOnEnd) {
				// move to correct position (enables buttons also)
				epages.event.fire(this.positionNode,'change');
			}

			// set html elements for undo
			if (this._htmlUndo) {
				if (positionChanged){
					this._htmlUndo.addInput(this.positionNode);
				}
				this._htmlUndo.addInput(this.navbarChangeNode);
			}
			dojo.publish('droplistNavBar'+this.navbar+'/change', []);
			this.adjustNewGhostEol();
		},

		adjustNewGhostEol: function() {
		// summary: correct position of new ghost (always last domnode)
			var navbarNodes=$('NavBar'+this.navbar,this.doc).childNodes;
			for(var el in navbarNodes){
				if(navbarNodes[el] !== undefined && navbarNodes[el].className=="Ghost New"){
					$('NavBar'+this.navbar,this.doc).appendChild(navbarNodes[el]);
				}
			}
		},

		onchangeNavbarChangeNode: function (evt) {
		// summary:
		//			called when NavbarChangeNode (idicates an navifation bar change)
		//			changed / adjusts elements navbar assignment and publish droplist
		//			change messages
		// tags:
		//			callback
			dojo.stopEvent(evt);
			this.setNavBar(this.navbarChangeNode.value, false);
			// publish change event to old and new droplists
			if(this.domNode.ep_droplistid) {
				dojo.publish('droplist'+this.domNode.ep_droplistid+'/change', []);
			}
			dojo.publish('droplistNavBar'+this.navbar+'/change', []);
			this.domNode.ep_droplistid='NavBar'+this.navbar;
		},

		onDropInList: function(/*Object*/options) {
		// summary:
		//			called by droplist handler / adjust new positon of navigation alement
		// tags:
		//			callback
			var newNavbarid = options.listObject.options.navbarid;
			//var newNavbarid = options.listContainer.options.navbarid;
			var successor = options.insertBefore;
			var isNewNavbar = this.navbar !== newNavbarid;
			if(isNewNavbar) {
				this.setNavBar(newNavbarid, true);  // always push to end insert
			}
			var wa = this._widgetsA[newNavbarid];
			if(successor != null && successor.className!="Ghost New") {
				var successorFound=false;
				for(var w in wa) {
					if(wa[w].domNode === successor) {
						var posPredecessor = (wa[w-1]) ? parseInt(wa[w-1].positionNode.value) : 0;
						var posSuccessor = parseInt(wa[w].positionNode.value);
						var posSuperSuccessor = (wa[w+1]) ? wa[w+1] : parseInt(wa[w].positionNode.value) + 10;
						var posDistance = parseInt((posSuperSuccessor-posPredecessor) / 3);
						var newPosDropped = posPredecessor + posDistance;
						var newPosSuccessor = posPredecessor + 2 * posDistance;
						var successorPositonNode = wa[w].positionNode;

						successorPositonNode.value = newPosSuccessor;
						epages.event.fire(successorPositonNode, 'change');

						this.positionNode.value = newPosDropped;
						epages.event.fire(this.positionNode, 'change');

						if (this._htmlUndo) {
							this._htmlUndo.addInput(successorPositonNode);
							this._htmlUndo.addInput(this.positionNode);
						}

						successorFound=true;
						break;
					}
				}
				if(!successorFound) {
					console.warn("Navigationelement.onDropInList: successor dom node not found");
				}
			} else if(!isNewNavbar) { // insert as last element
					var last = wa[wa.length - 1];
					var lastPos = parseInt(last.positionNode.value);
					this.positionNode.value = lastPos + 10;

					epages.event.fire(this.positionNode, 'change');

					if (this._htmlUndo){
						this._htmlUndo.addInput(this.positionNode);
					}
			}

			// fire click event to select navbar
			epages.event.fire($('NavBar'+this.navbar,this.doc), 'click');

			dojo.publish("Navigationelement/onDropInListFinished", []);
		},

		onclickEditNode: function (evt) {
		// summary:
		//			show dialog for customizable navigation elements
		// tags:
		//			callback
			if (evt !== undefined){
				 dojo.stopEvent(evt);
			}
			if (this._editorWidget === undefined) {   // create new dialog
				this.createEditDialog();
				this.initEditDialog();
			} else {                                  // dialog is already up and running
				this.resetEditDialogInputValues();
			}
			this.onbeforeShowDialog();
			this._editorWidget.show();
		},

		createEditDialog: function() {
		// summary:
		//			create edit dialog for customizable navigation elements
		// description:
		//  		load dialog data and instanciates diaolg within a modal dialog widget
		// tags:
		//			protected

			// load dialog template
			
			var json = new epages.io.Json();
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONSnippet',
				'TemplateAction': 'EditSnippet',
				'TemplateLanguageID': this.languageId,
				'ObjectID': this.objectId
			});

			// create and setup dialog
			var _navigationElementWidget = this;

			// Create an undo stack for dialogs
			top.epages.html.UnDo.prototype.undoNavigationElementWidgetStack.push(_navigationElementWidget);

			top.dojo["require"]('epages.widget.Modaldialog');
			var newDiv = top.document.createElement('div');												// dialog insert point
			top.document.getElementsByTagName('body')[0].appendChild(newDiv);
			var nameOrAlias = this.nameOrAlias != "" ? ": "+this.nameOrAlias : "";

			this._editorWidget = new top.epages.widget.Modaldialog({
				options:{
					title : _navigationElementWidget.translate('EditNavElement')+nameOrAlias,
					content: result.data.snippet,
          scroll: 'hidden'
				},
				buttons: [{
					label: _navigationElementWidget.translate('Apply'),
					cssClass: "Active",
					onclick: function() {
					// apply function - fire change on hidden element node
						this._modalDialogWidget.hide();
						_navigationElementWidget.applyEditorDialogInputValues();
						dojo.publish("Navigationelement/EditFinished", []);
					}
				}, {
					label: _navigationElementWidget.translate('Cancel'),
					onclick: function() {
					//cancel action, just hide dialog
						this._modalDialogWidget.hide();
						_navigationElementWidget.resetEditDialogInputValues();
					}
				}]
			}, newDiv);
		},

		initEditDialog: function() {
		// summary:
		//			called after edit dialog was created
		// description:
		//			registers all relevant input elements (inputs starting with "editor_" followed by ObjectID:Attributname:LanguageID e.g. editor_12345:MyAttribute:1)
		// tags:
		//			protected
			var undo = $$(this.undoWidgetId).undoObject;
			var _this = this;
			var iterator = dojo.hitch(this, function (el) {
			// parse dialog inputs, build a copy in parent window and register them to undo widget

				if (el.name === undefined || !el.name.match(/^editor_/)){
					return;		// skip unnamed inputs and inputs wich do not start with "editor_"
				}
				var hid = el.parentNode.ownerDocument.createElement('input');				// create a hidden input element in main window
				hid.name =el.name.substr(7);																				// cut "editor_" away
				hid.type ='hidden';
				hid.value = $E(el).get();																						// e.g. <input type="hidden" name="12345:MyAttribute" value="MyValue" />

				if(el.getAttribute("ep_noundo")=="1") {
					hid.setAttribute("ep_noundo","1");
				}

				var ep_publishmessage = el.getAttribute("ep_publishmessage");
				el.parentNode.appendChild(hid);
				_this._inputs.push({																								// save nodes to this._inputs array
					'editorNode' : el,																								// editor node (edit node in dialog) -> format example: <inupt type="hidden" name="editor_1234:Logo:1" value="myvalue" />
					'hiddenNode' : hid,																								// hidden input node (real value container for undo widget) -> <input type="hidden" name="1234:Logo::1" value="myvalue" />
					'ep_publishmessage' : ep_publishmessage														// pass input message identifier
				});
				undo.registerInput(hid);																						// register the hidden input node to undo widget
				epages.topDojo.connect(hid, 'onchange', _this, 'setPreview');				// connect inputs to preview function
			});

			// make copy because getElementsByTagName will be change during the iterator
			var aCopy = [];
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("input"), function (el) { aCopy.push(el); });
			dojo.forEach(aCopy, iterator);
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("select"),   iterator);
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("textarea"), iterator);
		},

		onbeforeShowDialog: function() {
		// summary:
		//			override function - called before dialog widget is shown
		// tags: callback extension protected
		},


		applyEditorDialogInputValues : function() {
		// summary:
		//			apply editor inputs (this._inputs) to hidden inputs (data storage)
			dojo.forEach(this._inputs, function (el) {
				var value = $E(el.editorNode).get();
				if(el.editorNode.type=='radio' || el.editorNode.type=='checkbox'){ // special handling for radio buttons
					if(el.editorNode.checked == true){
						el.hiddenNode.value = value;
						this.onbeforePreview(el.hiddenNode);
						epages.event.fire(el.hiddenNode,'change');
					}else{
			            var topLength = top.document.getElementsByName(el.hiddenNode.name).length;
			            var selfLength = document.getElementsByName(el.hiddenNode.name).length;

			            if(((topLength!==undefined)&&(topLength>1)) || ((selfLength!==undefined)&&(selfLength>1))){
			            	el.hiddenNode.value = "";
			            }

			        }
				} else if (el.hiddenNode.value != value) {											// fire only if value is different
					el.hiddenNode.value = value;
					this.onbeforePreview(el.hiddenNode);
					epages.event.fire(el.hiddenNode,'change');
				}
			}, this);
		},

		resetEditDialogInputValues: function() {
		// summary:
		//			reset input values / set values from hiddenNode
		//			(data storage to editor inputs (this._inputs)
		// tags:
		//			protected

			dojo.forEach(this._inputs, function (el) {
				var formElement = $E(el.editorNode);
				var elValue = formElement.get();
				var hiddenValue = el.hiddenNode.value;
				if(elValue != hiddenValue) {		// set value only if changed
					formElement.set(hiddenValue);
					formElement.callOnChange();
				}
			});
		},

		onbeforePreview: function(/*domnode*/ inputNode) {
		// summary:
		//			called before setPreview (change is fired on input node) -
		//			publishes a message on all input that have specified a message
		//			identifier (ep_publishmessage)
		// description:
		//			You may override this function but don't forget to call
		//			this.inherited("onbeforePreview", arguments);
		// inputNode:
		//			input node that has changed in dialog
		// tags:
		//			callback protected extension
			if(inputNode['ep_publishmessage']) {																// publish input specific message before change is fired, pass input node
				dojo.publish(inputNode['ep_publishmessage']+'/beforeChangeFired', [inputNode]);
			}
		},

		setPreview: function(evt) {
		// summary:
		//			update navigation element preview (called onchange: input node)
		// description:
		//      	Update content (texts / file url) of displayed naviagtion elements.
		//      	format example preview nodes: <img id="eid_1234:Logo:1" src="myurl" />
		// tags:
		//			callback protected
			var el = evt.target;																					// get input node (changed content)
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node
			if (node) {
				var value = el.value == '' ? this.emptyString : el.value;		// get value;
				if(node.nodeName.match(/input|textarea|select/i)) {					// set value to form fields
					node.value = value;
				} else if(node.nodeName.match(/img/i)) {										// set value to image
					node.src=el.value;
				} else {																										// set value as html content
					node.innerHTML = el.value == '' ? this.emptyString : el.value;
					node.innerHTML = epages.cartridges.de_epages.design.MceContent.prototype.string2Preview(node.innerHTML);
					epages.html.disableHrefsAndActions(node);
					this._adjustGeomtry(node);
				}
			} else {
				// no updates
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
		},

		_adjustGeomtry: function(node) {
		// summary:
		//			adjust gemoetry of the original navigation element / force minimal size
		// tags:
		//			protected
			dojo.removeClass(node, "ForceMinSize");
			var cn = node.className;
			if((node.clientWidth < 11 && node.offsetWidth < 11 ||
					node.clientHeight < 11 && node.offsetHeight < 11) &&
					cn.match("NavigationText")){
					dojo.addClass(node, "ForceMinSize");
			}
		},

		// dojoAttachEvent
		mouseenter_ButtonAndMetainfo: function() {
		// summary:
		//			show ButtonAndMetaInfo layer
		// tags:
		//			callback protected
			var el= this.elementNode();
			if(el) {
				dojo.addClass(el, "SetOver");
			}
		},

		mouseleave_ButtonAndMetainfo: function(evt) {
		// summary:
		//			hide ButtonAndMetaInfo layer
		// tags:
		//			callback protected
			var el_t = evt.target;
			var el_c = evt.currentTarget;
			var el= this.elementNode();
			if(el && el_t === el_c){
				dojo.removeClass(this.elementNode(), "SetOver");
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.ToolNewNavElement"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.ToolNewNavElement"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.design.widget.Toolsimpleinput $Revision: 1.20 $

*/

dojo.provide("epages.cartridges.de_epages.design.widget.ToolNewNavElement");







epages.cartridges.de_epages.design.widget.ToolNewNavElementDialog = undefined;

dojo.declare(
	"epages.cartridges.de_epages.design.widget.ToolNewNavElement",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		objectId        : '', // style id
		navBar          : '', // navbar name
		languageId      : epages.vars.Locale.languageId,// language for snippet
		url             : '?',
		shopId          : epages.vars.SiteID, // shop identifier for feature request

		/**
		 * privat properties
		 */
		_disabledUserDefined : false,
		_isScrolling         : false, 				// flag - indcates that scrolling is active at the moment
		_modalDialog         : undefined,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolNewNavElement WithXLIcon\">\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\" dojoAttachEvent=\"onclick:onOpenClick\">\n    <i class=\"Sprite ico_xl_navelement_new\" title=\"{CreateNewPageElement}\"></i><br />\n    {New}\n  </div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),
		navBarSelectTemplate: '<b class="RightPadding">{InsertElementToArea}</b>',

		insertToNavbar: function(/* string */ navbar) {
			this.navBar = navbar;
			this.onOpenClick();
		},

		onOpenClick: function (/* event */ evt, /* string? */ highlightArea, /* string? */ selectElement) {
		// summary: open insert dialog (creates and initalizes the dialog content)
		// parameters
		//  evt            passed event object
		//  highlightArea  alias of navbar group e.g. Default (scroll to that area)
		//  selectElement  alias of element e.g. Default

			// hide NavbarSelection if exists
			var nsNode = $('NavbarSelection');
			if(nsNode) {
				nsNode.style.display="none";
			}
			if(this._modalDialog) {
				this._modalDialog.showInnerButtonBar();
			}

			//check UserDefinedNavBarElements Feature and UserDefinedNavBarElementCount
			var json = new epages.io.Json();
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONGet',
				'Attributes': 'UserDefinedNavBarElementCount',
				'ObjectID'  : this.objectId
			});
			if(!result.error){
				var userDefinedNavBarElementCount = result.data.UserDefinedNavBarElementCount;
			}
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONGetFeature',
				'Features'  : 'UserDefinedNavBarElements',
				'ObjectID'  : this.shopId
			});
			if(!result.error){
				var userDefinedNavBarElements = result.data.UserDefinedNavBarElements.max;
			}

			// create / open dialog widget
			var widgetFolder = epages.cartridges.de_epages.design.widget;
			if (widgetFolder.ToolNewNavElementDialog === undefined) {
				
				var json = new epages.io.Json();
				var result = json.loadSync(this.url, {
					'ViewAction': 'JSONSnippet',
					'TemplateAction': 'NewNavElementSnippet',
					'TemplateLanguageID': this.languageId,
					'ObjectID': this.objectId
				});
				var w = new epages.widget.Modaldialog({
					'class' : 'ContentNoPadding',
					options:{
						title:   this.translate('CreateNewPageElement'),
						content: result.data.snippet,
						width : 810,
						height: 450,
						scroll: "hidden",  // y, x, scroll
						toolBox: this
					},
					buttons: [{
						label: this.translate('Insert'),
						cssClass: 'Active',
						buttonId : 'Insert',
						onclick: function() {
							this._modalDialogWidget.options.toolBox.onNewClick(this._modalDialogWidget.domNode);
						}
					}, {
						label: this.translate('Cancel'),
						onclick: function() {
							this._modalDialogWidget.options.toolBox.onAbortClick(this._modalDialogWidget.domNode);
						}
					}]
				});
				top.document.body.appendChild(w.domNode);
				widgetFolder.ToolNewNavElementDialog = w;
				this._modalDialog = w;

				// assign events to dialog elements
				var _this = this;
				var navElementLines = dojo.query(".ListRow.ItemLine", w.domNode);						// get all navelement types
				dojo.forEach(navElementLines, function(el) {
					var classname = el.className;
					if(!classname.match("FeatureDisabled")) {
						_this.connect(el, "onclick", "setSelectedNavElement");
					}
				});

				var selectElementLinks = dojo.query(".SelectNavElementGroup", w.domNode);		// get all navelement groups
				dojo.forEach(selectElementLinks, function(el) {
					_this.connect(el, "onclick", "evtSlideToNavElementGroup");
				});

				this.connect(window, "keypress", "onKeypress");
				dojo.subscribe('InsertElementNavbarpreview/select', this, '_selectNavbar');

			} else {
				widgetFolder.ToolNewNavElementDialog.options.toolBox=this;
			}

			// reset form (unselect all checkboxes)
			var newNavElementDialog = widgetFolder.ToolNewNavElementDialog;
			var newform=newNavElementDialog.containerNode.getElementsByTagName("form")[0];
			if(newform){
				newform.reset();
			}

			// highlight navelement group
			if(highlightArea) {
				var groupNo = epages.vars.navElementGroupMapping[highlightArea];
				if(groupNo) {
					this.slideToNavElementGroup(groupNo, 2000);
				}
			} else {
				this.slideToNavElementGroup(0, 500);
			}

			// preselect navelement
			var nodes = dojo.query("[ep_alias="+selectElement+"]", this._modalDialog.domNode);
			dojo.forEach(nodes, function(el) {
				epages.event.fire(el, "click");
				// wait because there is an animation
				window.setTimeout(function(){
					var offTop = el.offsetTop - 90; // 90 = head area hight
					var pNode = el.parentNode;
					offTop = (offTop > 0) ? offTop : 0;
					pNode.scrollTop = offTop;
				}, 100);
			});

			if(userDefinedNavBarElements != null && userDefinedNavBarElementCount != null){
				var userdefinedItems = $('SlideUserDefined');
				var elements = dojo.query("[ep_feature=UserDefinedNavBarElements]", userdefinedItems);

				if(userDefinedNavBarElementCount >= userDefinedNavBarElements){
					//disable
					this._disabledUserDefined = true;
					//disable UserDefined Navbar and add FeatureLimitReached Message
					for( var i=0,iLength=elements.length ; i<iLength ; i++ ){
						dojo.addClass(elements[i], 'FeatureDisabled');
						dojo.removeClass(elements[i], 'EnableHover');
						elements[i].title=this.translate('FeatureLimitReached');
					}
				} else if(this._disabledUserDefined == true){
					this._disabledUserDefined = false;
					//enable UserDefined Navbar and remove FeatureLimitReached message
					for( var i=0,iLength=elements.length ; i<iLength ; i++ ){
						dojo.removeClass(elements[i], 'FeatureDisabled');
						dojo.addClass(elements[i], 'EnableHover');
						elements[i].title='';
					}
				}
			}

			//need Timeout for Position error to avoid wrong position of dialog
			window.setTimeout(dojo.hitch(this,function(){
				newNavElementDialog.show();
			}),1);

		},

		onAbortClick: function(node) {
			this._hideDialog();
		},

		_showNavBarSelectLayer: function() {
			var nsNode = $('NavbarSelection');
			nsNode.style.display="";
			this._modalDialog.hideInnerButtonBar();
		},

		_selectNavbar: function(opt) {
			this.navBar = opt.navbar;
			this._insertNewElement();
		},

		_hideDialog: function() {
			this._modalDialog.hide();
			var nsNode = $('NavbarSelection');
			nsNode.style.display="none";
			this._modalDialog.showInnerButtonBar();
		},

		_insertNewElement : function() {
			this._hideDialog();
			dojo.publish("uimessage/startBusy", ["ToolNewNavElement", this.translate("InsertingPageElement")]);
			var newNavElementDialog = epages.cartridges.de_epages.design.widget.ToolNewNavElementDialog;
			var targetNavBar = this.navBar;
			if(newNavElementDialog.navBarSelectorNode !== undefined && this.navBar == '' && newNavElementDialog.navBarSelectorNode.value){
				targetNavBar = newNavElementDialog.navBarSelectorNode.value;
			}
			var widgets = [];
			var n = epages.cartridges.de_epages.design.widget.Navigation;

			// create new navelement widget
			var el = $('NavelementsAddID');
			var w = n.createElement(el.value, this.objectId, targetNavBar);
			if(w == false) {
				console.warn('Navelement',this.id,'can not create Element');
				return false;
			} else {
				var starNode = $('ItemStarContainer'+el.value);
				if(starNode) {
					starNode.innerHTML="*";
				}
			}
			if (w.isCustomizable){ 
				widgets.push(w);
			}

			if (widgets.length == 1){ 
				widgets[0].onclickEditNode();
			}
			dojo.publish("uimessage/stopBusy", ["ToolNewNavElement"]);
			dojo.publish("ToolNewNavElement/onNewClickFinshed",[]);
		},

		onNewClick:function (node) {
			if(this.navBar != "") {
				this._insertNewElement();
			} else {
				this._showNavBarSelectLayer();
			}
		},

		setSelectedNavElement: function(/* event or string */ evt) {
		// summary: set navelementtype id to hidden input
			var newId = (evt != "") ? evt.currentTarget.getAttribute("ep_objectId") : "";			// event or empty string
			if(evt) {
				dojo.stopEvent(evt);	// don't pass click to body to avoid cssfix updateStyle
			}
			var classname = "";
			if(evt) {
				classname = evt.currentTarget.className;
			}

			var hiddenInputNode = $('NavelementsAddID');
			var oldId = hiddenInputNode.value;
			if(newId == oldId || classname.match("FeatureDisabled")) {  // deselect if its the same value again or feature not allowed
				newId="";
			}

			hiddenInputNode.value=newId;

			var pesaNode = $('PageElementsScrollArea');
			var selNodes = dojo.query(".Selected", pesaNode);

			//remove old selection
			if(selNodes) {
				dojo.forEach(selNodes, function(node) {
					dojo.removeClass(node, "Selected");
				});
			}

			if(newId != "") {
				var newSelectedDiv = $('ListRowPageElement_'+newId);
				dojo.addClass(newSelectedDiv, "Selected");
				this._modalDialog.enableButton("Insert");
			} else {
				this._modalDialog.disableButton("Insert");
			}
		},

		slideToNavElementGroup: function(/* integer */ itemNo , /* integer? */ delay) {
		//summary: slides the screen to specfied page element category
			this._isScrolling = true;
			if(!delay) {
				delay=0;
			}

			//reset selection selection display
			this.setSelectedNavElement("");

			var x = itemNo * 810 * -1;
			var fsblNode = $('FancySidebarLinks');
			var selNodes = dojo.query(".Selected", fsblNode);
			for(var el in selNodes) {
				dojo.removeClass(selNodes[el], "Selected");
			}

			var node = $('SelectNavElementGroup'+itemNo);
			if(node) {
				dojo.addClass(node, "Selected");
			}

			var pesaNode = $('PageElementsScrollArea');
			var listWrapperNodes = dojo.query(".SlideListContent",pesaNode);

			dojo.forEach(listWrapperNodes, function(node) {
				node.style.overflowY="hidden";
			});
			var _this = this;
			dojo.fx.slideTo({
				node: $('PageElementsScrollArea'),
				left: x,
				top: "0",
				unit:"px",
				delay: delay,
				duration: 650,
				easing: dojo.fx.easing.quadOut,
				onEnd: function() {
					dojo.forEach(listWrapperNodes, function(node) {
						node.style.overflowY="auto";
					});
					_this._isScrolling = false;
				}
			}).play();
		},

		evtSlideToNavElementGroup: function(evt)  {
		// summary: catch event props and then start to slide
			dojo.stopEvent(evt);	// don't pass click to body to avoid cssfix updateStyle
			if(!this._isScrolling) {
				var node = evt.currentTarget;
				itemNo = node.getAttribute("ep_groupcount");
				this.slideToNavElementGroup(itemNo);
			}
		},


		onKeypress: function(evt) {
		// summary: keypress event handler
			if(evt.keyCode == dojo.keys.ESCAPE) {		// deselect on ESCAPE
				this.setSelectedNavElement("");
			}
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementLogo']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementLogo'] = true;
dojo.provide('epages.cartridges.de_epages.design.widget.NavigationelementLogo');



dojo.declare(
	"epages.cartridges.de_epages.design.widget.NavigationelementLogo",
	[epages.cartridges.de_epages.design.widget.Navigationelement],
	{

	initEditDialog : function() {
	//summary:
	//			initalize widgets in dialog / subscribe to topics
		this.inherited("initEditDialog", arguments);
		top.dojo.subscribe('LogoDialogFilebrowser'+this.objectId+'Filelist/select', function(/* FileListItem */ item) {
		// publish generalized message (for use of more than one logo widget)
			dojo.publish("LogoDialogFilebrowserFilelist/select", [item]);
		});

		// subscribe to generalized message
		//dojo.subscribe("LogoDialogFilebrowserFilelist/select", this, 'synchronizeLogo');

		// cut away media gallery path
		/*var filenameNode = top.$('LogoDialogName'+this.objectId);
		var filename = filenameNode.innerHTML;
		filename = filename.replace(/MediaGallery\//, "");
		filenameNode.innerHTML=filename;*/
	},

	synchronizeLogo : function(/* FileListItem */item) {
	// summary:
	//			update logo preview widget, logoname and filesize in dialog
		if(item.fullpath.match("MediaGallery")) {       // only Mediagallery files / skip image db
			var logoPrev = top.$$('LogoDialogPreview'+this.objectId);
			logoPrev.addImage({ image: item.fullpath }, true);

			var lnNode = top.$('LogoDialogName'+this.objectId);
			dojo.addClass(lnNode, "Bold");
			lnNode.innerHTML = item.name;

			var liNode = top.$('LogoDialogInfo'+this.objectId);
			liNode.innerHTML ="("+item.imagewidth + " x "+item.imageheight+" / "+item.size+")";

			var inpNode = top.$('LogoDialogNameInput'+this.objectId);
			inpNode.value=item.fullpath;

			var mNode = top.$('LogoDialogOnApplyMessage'+this.objectId);
			mNode.style.display="";
		}
	},

	onbeforePreview: function(/* domnode */ inputNode) {
	// summary:
	//			shows busylayer before the logo got modified
	// inputNode:
	//			input node that has changed in dialog
		this.inherited("onbeforePreview", arguments);

		var name = inputNode.name;

		if(name.match("Logo")) { // logo name node was changed
			top.dojo.publish("uimessage/startBusy", ["logoPreviewupdate", this.translate("UpdatingLogoPreview")]);

			// do request to generate new logo
			var value = inputNode.value;
			value = value.replace(epages.vars.SiteRoot+'/', "");
			
			var json = new epages.io.Json();

			var result = json.loadSync(this.url, {
				'ChangeAction' : 'SaveLogo',
				'Logo'         : value,
				'ObjectID'     : epages.vars.SiteID,
				'ViewAction'   : 'JSONViewResponse'
			});

			// modify node value (all logos used in style object are named as logo.<old extension>)
			var splitArr = value.split(".");
			var ext = undefined;
			if(splitArr.length) {
				ext = splitArr[splitArr.length-1];
			}

			if(ext) {
				inputNode.value=top.epages.vars.EditorStyleWebPath+'/logo.'+ext;
			}

			if(! top.epages.vars.EditorStyleWebPath) {
				console.warn("top.epages.vars.EditorStyleWebPath not defined in "+this.declaredClass);
			}
		}
	},

	setPreview: function(evt) {
	// summary:
	//			update preview for all logo navelements (onchange: input node)
			var el = evt.target;																					// get input node
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node

			if(node) {
				var value = el.value == '' ? this.emptyString : el.value;		// get value;
				var NavigationElements = dojo.query('.NavigationElementWidget');
				var logoWidget = undefined;

				for( var i=0,iLength=NavigationElements.length ; i<iLength ; i++ ){
					var navElWidget = $$(NavigationElements[i].id);
					var ShopLogoNodes = dojo.query('.ShopLogo',navElWidget.contentNode);   // has logo?
					if(ShopLogoNodes.length != 0) {
						navElWidget.setLogo(value);

						// reset all filebrowser widgets (open root folder)
						var fileBrowser = top.$$('LogoDialogFilebrowser'+navElWidget.objectId);
						if(fileBrowser) {
							fileBrowser.openRootFolder();
						}

					}
				}
			} else {
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
			top.dojo.publish("uimessage/stopBusy", ["logoPreviewupdate", 1500]);
		},

		setLogo : function(/* string */ value) {
		// summary:
		//			set src attribute of logo node
			var logoNode = $('eid_'+this.objectId+':Logo:'+this.languageId);
			if(logoNode) {
				var date = new Date();
				logoNode.src=value+'?CachePrevention='+date.getTime();
			} else {
				console.warn('logo node not found in '+this.declaredClass);
			}
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementIcon']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementIcon'] = true;
dojo.provide('epages.cartridges.de_epages.design.widget.NavigationelementIcon');


dojo.declare(
	"epages.cartridges.de_epages.design.widget.NavigationelementIcon",
	[epages.cartridges.de_epages.design.widget.Navigationelement],
	{

	_ICON_SIZES : ['S', 'M', 'L', 'XL'],	// array - array with possible icon size stings

	setPreview: function(evt) {
	// summary:
	//			update preview of icon
			var el = evt.target;																					// get input node
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node
			if (node) {
				for(var e in this._ICON_SIZES) {
					dojo.removeClass(node, this._ICON_SIZES[e])
				}
				dojo.addClass(node, el.value);
			} else {
				// no updates
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
		}

});

}

if(!dojo._hasResource['epages.event.selectables']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.event.selectables'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.event.selectables $Revision: 1.33 $

*/
dojo.provide('epages.event.selectables');





epages.event.Selectables = epages.Class();

epages.event.Selectables.prototype = {
	selectables:        undefined,
	currentSelected:    undefined,
	currentHighlighted: undefined,
	callback:           undefined,
	strHighlighted: 'Highlighted',
	strUnselected:  'Unselected',
	strSelected:    'Selected',
	selectionGuides : undefined,

	initialize: function(/*ArrayLike*/enumselectables, doc) {
		if(doc === undefined){
			doc = document;
		}
		var win = epages.getDocumentWindow(doc);
		if (this.selectables === undefined){
			this.selectables = new Array();
		}
		var sel = this.selectables;
		var existsUndefined = -1;
		var counter = -1;
		this.selectionGuides = {};

		this.selectionGuides.North = doc.createElement("div");
		this.selectionGuides.South = doc.createElement("div");
		this.selectionGuides.West  = doc.createElement("div");
		this.selectionGuides.East  = doc.createElement("div");
		for(var item in this.selectionGuides) {
			var div = this.selectionGuides[item];
			div.className="SelectionGuide "+item;
			doc.getElementsByTagName("body")[0].appendChild(div);
		}

		$A(enumselectables).each(function(el) {
			counter++;
			if (el) {
				sel.push(el);

					var contentDiv = win.dojo.query(".ContentAreaInner", el)[0];
					var effectLayer = el.ownerDocument.createElement("div");
					effectLayer.className = "EffectLayer";

					if(el.tagName.toLowerCase() == "td") {
						effectLayer.style.marginLeft = "-" + el.getElementsByTagName("div")[0].offsetLeft + "px";
						effectLayer.style.marginTop = "-" + el.getElementsByTagName("div")[0].offsetTop + "px";
					}

					if(contentDiv && epages.Browser.engine == "MSIE" || el.attributes["class"].nodeValue.indexOf("ContentArea") > -1 && el.tagName.toLowerCase() == "div"){
						el.style.position = "relative";
						dojo.style(effectLayer, {
							left : "0",
							top  :"0",
							marginLeft : "0",
							marginTop  : "0"
						});
					}
					el.insertBefore(effectLayer, el.firstChild);

					//ugly way to check if element has been resized...do not have a better idea for now
					var tempResizeCheck = function() {
						if(parseInt(effectLayer.style.height) != el.offsetHeight) {
							effectLayer.style.height = el.offsetHeight + "px";
						}
						if(parseInt(effectLayer.style.width) != el.offsetWidth) {
							effectLayer.style.width = el.offsetWidth + "px";
						}
					};

					dojo.connect(window, "resize", tempResizeCheck);
					dojo.subscribe('selectables/SetSelectionGuidelines',tempResizeCheck);
			}else if (existsUndefined == -1) {
				existsUndefined = counter;
			}
		});
		if (existsUndefined != -1){
			console.warn('element ' + existsUndefined + ' is not defined and can\'t be selected');
		}
		dojo.connect(window, "resize", this,"setSelectionGuides");
		dojo.connect($("EmbeddedStorefront"), "resize", this, "setSelectionGuides");

		this.preparePage();
	},

	unselect: /*void*/function(/*HTMLElement*/sel) {
		var className = sel.className.replace(this.strHighlighted,this.strUnselected).replace(this.strSelected,this.strUnselected);
		if ( !className.match( this.strUnselected )){
			className += ' ' + this.strUnselected;
		}
		sel.className = className;
	},

	reEnterElement: /*void*/function (/*HTMLElement*/sel) {
		this.unselect(sel);
		this.appendEvents(sel);
		if(sel == this.currentSelected){
			this.currentSelected = undefined;
		}
		this.selectables.push(sel);
	},

	destroy: /*void*/function () {
		for( var i=0,l=this.selectables.length ; i<l ; i++ ) {
			var className = this.selectables[i].className;
			[this.strHighlighted, this.strUnselected, this.strSelected].each(function (str) {
				className.replace(str,'');
			});
			this.selectables[i].className = className;
		}
	},

	appendEvents: /*void*/function(/*HTMLElement*/sel) {
		if(sel.tagName == "BODY" && epages.Browser.engine == "MSIE") {
			sel.onmouseover = function() {
				this.setCapture();
			};
			sel.onmouseout = function() {
				this.releaseCapture();
			};
		}
		dojo.connect(sel, 'onmouseover', this, 'onMouseOver');
		dojo.connect(sel, 'onmousedown', this, 'onClick');
		dojo.connect(sel, 'onclick', this, 'onClick');
	},

	preparePage: /*void*/function() {
		for( var i=0,l=this.selectables.length ; i<l ; i++ ) {
			var sel = this.selectables[i];
			this.unselect(sel);
			this.appendEvents(sel);
		}
	},

	onMouseOver: /*void*/function(/*Event*/evt) {
		dojo.stopEvent(evt);
		if(!$("EmbeddedStorefront").contentWindow.epages.html.getElementsByClassName("IsDragging", evt.currentTarget)[0]) {
			var newHighlighted = evt.currentTarget;
			if(!this.oldHighlighted) {
				this.oldHighlighted = newHighlighted;
			}
			if(this.oldHighlighted != newHighlighted) {
				epages.html.replaceClass(this.oldHighlighted, this.strUnselected, this.strHighlighted);
				epages.html.replaceClass(newHighlighted, this.strHighlighted, this.strUnselected);
				this.oldHighlighted = newHighlighted;
			}
		}
	},

	onClick: /*void*/function(/*Event*/evt) {
		dojo.stopEvent(evt);
		var newSelected = evt.currentTarget;
		if(newSelected != this.currentSelected) {
			var oldSelected = this.currentSelected;
			if (oldSelected !== undefined) {
				epages.html.replaceClass(oldSelected, this.strUnselected, this.strSelected);
				epages.html.replaceClass(oldSelected, this.strUnselected, this.strHighlighted);
			}
			epages.html.replaceClass(newSelected, this.strSelected, this.strUnselected);
			epages.html.replaceClass(newSelected, this.strSelected, this.strHighlighted);
			this.currentSelected = newSelected;
			if (this.callback !== undefined){
				this.callback(oldSelected, newSelected, evt);
			}
			this.setSelectionGuides();
		}
	},

	setSelectionGuides: function() {
		if(this.currentSelected) {
			var el = $E(this.currentSelected);
			var pos = el.getAbsolutePosition();

			pos.width = this.currentSelected.offsetWidth;
			pos.height = this.currentSelected.offsetHeight;

			//insert some jquery magic because dojo magic is calcuating wrong in this case
			var posJq = jq(this.currentSelected).offset();
			pos.x = posJq.left;
			pos.y = posJq.top;

			pos.x2 = pos.x + pos.width -1;
			pos.y2 = pos.y + pos.height -1;

			this.selectionGuides.East.style.top = pos.y+"px";
			this.selectionGuides.East.style.height = pos.height+"px";
			this.selectionGuides.East.style.left = pos.x+"px";

			this.selectionGuides.West.style.top = pos.y+"px";
			this.selectionGuides.West.style.height = pos.height+"px";
			this.selectionGuides.West.style.left = pos.x2+"px";

			this.selectionGuides.North.style.top = pos.y+"px";
			this.selectionGuides.North.style.width = pos.width+"px";
			this.selectionGuides.North.style.left = pos.x+"px";

			this.selectionGuides.South.style.top = pos.y2+"px";
			this.selectionGuides.South.style.width = pos.width+"px";
			this.selectionGuides.South.style.left = pos.x+"px";
		}
		dojo.publish('selectables/SetSelectionGuidelines');
	}
};

}

if(!dojo._hasResource['epages.event.displaydispatcher']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.event.displaydispatcher'] = true;
/*  EPages DesignToolbars JavaScript module, $Revision: 1.18 $
 *  (c) 2006 ePages GmbH
 *--------------------------------------------------------------------------
 */
dojo.provide('epages.event.displaydispatcher');



epages.event.DisplayDispatcher = function() {};

epages.event.DisplayDispatcher.prototype = {
	currentActiveID   : undefined,

	add: function(slaveID, masterClassName, doc) {
	  var doc = doc || dojo.doc;
	  var win = epages.getDocumentWindow(doc);
	  if (masterClassName == null) {
	  	// no class given => body
			var firstMaster = doc.body;
		} else {
			// find first node with given class
			var firstMaster = win.dojo.query("." + masterClassName, doc.body)[0];
		}
		if(firstMaster) {
			var me = this;
			var eventListenerCallback = function (evt) {
				dojo.stopEvent(evt);
				me.switchTo(slaveID);
			};
			if (firstMaster.addEventListener) {
				// W3C
				firstMaster.addEventListener("click", eventListenerCallback, false);
			} else {
				// IE
				firstMaster.attachEvent("onclick", eventListenerCallback);
			}
		}
	},

	switchTo: function(slaveID) {
		if(this.currentActiveID != slaveID) { // switch only if a different area is shown
			var s = $(slaveID);

			if (typeof (s.show) == 'function'){
				s.show();
			}
			else if(dojo.hasClass(s, 'NavBarInvisible')) {
				// if first child is a comment, then insert as innerHTML and parse it
				if (s.firstChild.nodeType == 8) {
					// using timeout for quicker and smoother fadein
					window.setTimeout(function() {
						s.innerHTML = s.firstChild.data;
						dojo.parser.parse(s);
						var navBarName = slaveID.replace(/^Tools(?:NavBar)?/i, '');
						dojo.publish('displaydispatcher/onCreateToolbar', [navBarName, s]);
					}, 1);
				}
			  epages.html.replaceClass(s, 'NavBarVisible', 'NavBarInvisible');
			}else{
				s.style.display = "block";
			}

			if (this.currentActiveID !== undefined) {
				var c = $(this.currentActiveID);
				if (typeof (c.hide) == 'function'){
					c.hide();
				}else if(dojo.hasClass(c, 'NavBarVisible')) {
				  epages.html.replaceClass(c, 'NavBarInvisible', 'NavBarVisible');
				}else{ 
					c.style.display = "";
				}
			}
			this.currentActiveID=slaveID;
		}
	}
};

}

